<?php
/**
 * @version 1.0 $Id: controller.php
 * @package Joomla
 * @subpackage Restaurant Guide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * Restaurant Guide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * Restaurant Guide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RESTAURANT GUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');

/**
 * Restaurant Guide Component Controller
 *
 * @package Joomla
 * @subpackage Restaurant Guide
 * @since 1.0
 */
class restaurantguideController extends JController
{
	function __construct( $config = array() )
	{
		// Require the generic restaurantguideView
		if ( JFile::exists( $path = RESTAURANTGUIDE_VIEW ) ) {
			require_once($path);
		} else {
			JError::raiseError( 404, get_class($this) . '::_construct() : cannot find RestaurantGuide generic view, located at: ' . $path );
		}
		
		parent::__construct($config);

		// Register Extra task
		$this->registerTask( 'apply', 			'save' );
		$this->registerTask( 'saveandnew', 		'save' );
		$this->registerTask( 'applycss', 		'savecss' );
	}

	/**
	 * Display the view
	 */
	function display( $cachable = false )
	{
		// Set a default view if none exists
		if ( !JRequest::getCmd('view') ) {
			JRequest::setVar( 'view', 'restaurantguide' );
		}

		parent::display($cachable);
	}

	function &getView( $name = '', $type = '', $prefix = 'restaurantguideView', $config = array() )
	{
		if ( empty($type) ) {
			$document	=& JFactory::getDocument();
			$type		= $document->getType();
		}
		
		if ( empty($prefix) ) {
			$prefix = 'restaurantguideView';
		}
		
		$view =& parent::getView( $name, $type, $prefix, $config );
		
		return $view;
	}
	
	function &getModel( $name = '', $prefix = 'restaurantguideModel', $config = array() )
	{
		$model =& parent::getModel( $name, $prefix, $config );
		
		return $model;
	}
	
	/**
	 * Saves the css
	 *
	 */
	function savecss()
	{
		global $mainframe, $option;

		JRequest::checkToken() or jexit( 'Invalid Token' );

		// Initialize some variables
		$option			= JRequest::getVar('option');
		$filename		= JRequest::getVar('filename', '', 'post', 'cmd');
		$filecontent	= JRequest::getVar('filecontent', '', '', '', JREQUEST_ALLOWRAW);

		if (!$filecontent) {
			$mainframe->redirect('index.php?option='.$option, JText::_('OPERATION FAILED').': '.JText::_('CONTENT EMPTY'));
		}

		// Set FTP credentials, if given
		jimport('joomla.client.helper');
		JClientHelper::setCredentialsFromRequest('ftp');
		$ftp = JClientHelper::getCredentials('ftp');

		$file = JPATH_SITE.DS.'components'.DS.'com_restaurantguide'.DS.'assets'.DS.'css'.DS.$filename;

		// Try to make the css file writeable
		if (!$ftp['enabled'] && JPath::isOwner($file) && !JPath::setPermissions($file, '0755')) {
			JError::raiseNotice('SOME_ERROR_CODE', 'COULD NOT MAKE CSS FILE WRITABLE');
		}

		jimport('joomla.filesystem.file');
		$return = JFile::write($file, $filecontent);

		// Try to make the css file unwriteable
		if (!$ftp['enabled'] && JPath::isOwner($file) && !JPath::setPermissions($file, '0555')) {
			JError::raiseNotice('SOME_ERROR_CODE', 'COULD NOT MAKE CSS FILE UNWRITABLE');
		}

		if ($return)
		{
			$task = JRequest::getVar('task');
			switch($task)
			{
				case 'applycss' :
					$mainframe->redirect('index.php?option='.$option.'&view=editcss', JText::_('CSS FILE SUCCESSFULLY ALTERED'));
					break;

				case 'savecss'  :
				default         :
					$mainframe->redirect('index.php?option='.$option, JText::_('CSS FILE SUCCESSFULLY ALTERED') );
					break;
			}
		} else {
			$mainframe->redirect('index.php?option='.$option, JText::_('OPERATION FAILED').': '.JText::sprintf('FAILED TO OPEN FILE FOR WRITING', $file));
		}
	}
}
?>