<?php
/**
 * @version 1.0 $Id: admanagers.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');


/**
 * RestaurantGuide Component AdManager Controller
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since 1.0
 */
class restaurantguideControllerAdManagers extends restaurantguideController
{

	function __construct()
	{
		parent::__construct();

		// Register Extra task
		$this->registerTask( 'add', 'edit' );
		$this->registerTask( 'apply', 'save' );
	}

	/**
	 * Logic to save an item
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function save()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		jimport('joomla.filesystem.file');
		jimport('joomla.filesystem.archive');
		require_once (RESTAURANTGUIDE_ADMINISTRATOR.DS.'lib'.DS.'class.upload.php');
		
		$task = JRequest::getVar('task');

		$post = JRequest::get( 'post' );
		$post['description'] = JRequest::getVar( 'description', '', 'post', 'string', JREQUEST_ALLOWRAW );

		$model = $this->getModel('admanager');
		$data = $model->getFile($post['id']);

		if (isset($_FILES['file_upload'])){
		
			$handle = new Upload($_FILES['file_upload']);

			if ($handle->uploaded) {
				$dir =  RESTAURANTGUIDE_IMAGES_BANNER.DS;
		
				if (!file_exists($dir)) {
					mkdir($dir, 0777);
				}

				$handle->jpeg_quality = 100;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$width = $handle->image_src_x;
				$height = $handle->image_src_y;
				$handle->file_new_name_body = $file_body;
				$handle->Process($dir);

				$post['filename'] = $handle->file_dst_name;	
				$post['imagewidth'] = $width;
				$post['imageheight'] = $height;

				$handle->Clean();
			}
		}
		
		if ( $model->store($post) ) {

			switch ($task)
			{
				case 'apply' :
					$link = 'index.php?option=com_restaurantguide&view=admanager&cid[]='.(int) $model->get('id');
					break;

				default :
					$link = 'index.php?option=com_restaurantguide&view=admanagers';
					break;
			}
			$msg = JText::_( 'RG_ITEM_SAVED' );

			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();

		} else {
			$msg = JText::_( 'RG_ERROR_SAVING_ITEM' );
			JError::raiseError( 500, $model->getError() );
			$link 	= 'index.php?option=com_restaurantguide&view=admanager';
		}
		
		$model->checkin();
		
		$this->setRedirect($link, $msg);
	}

	/**
	 * Logic to orderup an item
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function orderup()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('admanagers');
		$model->move(-1);

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=admanagers');
	}

	/**
	 * Logic to orderdown an item
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function orderdown()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('admanagers');
		$model->move(1);

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=admanagers');
	}

	/**
	 * Logic to mass ordering items
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function saveorder()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$order 	= JRequest::getVar( 'order', array(0), 'post', 'array' );

		$model = $this->getModel('admanagers');
		if(!$model->saveorder($cid, $order)) {
			$msg = '';
			JError::raiseError(500, $model->getError());
		} else {
			$msg = JText::_( 'RG_NEW_ORDERING_SAVED' );
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=admanagers', $msg );
	}

	/**
	 * Logic to change the state
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function setitemstate()
	{
		$id 	= JRequest::getInt( 'id', 0 );
		$state 	= JRequest::getVar( 'state', 0 );

		$model = $this->getModel('admanagers');

		if(!$model->setitemstate($id, $state)) {
			JError::raiseError(500, $model->getError());
		}

		if ( $state == 1 ) {
			$img = 'tick.png';
			$alt = JText::_( 'RG_PUBLISHED' );
		} else if ( $state == 0 ) {
			$img = 'publish_x.png';
			$alt = JText::_( 'RG_UNPUBLISHED' );
		} 
		$cache = &JFactory::getCache('com_restaurantguide');
		$cache->clean();

		echo '<img src="images/'.$img.'" width="16" height="16" border="0" alt="'.$alt.'" />';
	}

	/**
	 * Logic to delete items
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function remove()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid		= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			JError::raiseError(500, JText::_( 'RG_SELECT_ITEM_DELETE' ) );
		}

		$model = $this->getModel('admanagers');

		if(!$model->delete($cid)) {
			$msg = '';
			JError::raiseError(500, $model->getError());
		} else {
			$total 	= count( $cid );
			$db 	=& JFactory::getDBO();

			for ($i = 0; $i < $total; $i++) {


			}

			$msg 	= $total.' '.JText::_($directory);

			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=admanagers', $msg );
	}

	/**
	 * logic for cancel an action
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function cancel()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		$item = & JTable::getInstance('rg_admanagers', '');
		$item->bind(JRequest::get('post'));
		$item->checkin();

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=admanagers' );
	}

	/**
	 * Logic to create the view for the edit categoryscreen
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function edit( )
	{		
		JRequest::setVar( 'view', 'admanager' );
		JRequest::setVar( 'hidemainmenu', 1 );

		$model 	= $this->getModel('admanager');
		$user	=& JFactory::getUser();

		// Error if checkedout by another administrator
		if ($model->isCheckedOut( $user->get('id') )) {
			$this->setRedirect( 'index.php?option=com_restaurantguide&view=admanagers', JText::_( 'RG_EDITED_BY_ANOTHER_ADMIN' ) );
		}

		$model->checkout( $user->get('id') );

		parent::display();
	}

	function removeFile($srcFilename, $srcFilePath) {
		$removeFilename = $srcFilePath . $srcFilename;
		if (unlink($removeFilename)) {
			return true;
		}
		else {
			return false;
		}
	}
}