<?php
/**
 * @version 1.0 $Id: galleryitems.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');


/**
 * RestaurantGuide Component Gallery Item Controller
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since 1.0
 */
class restaurantguideControllerGalleryItems extends restaurantguideController
{

	function __construct()
	{
		parent::__construct();

		// Register Extra task
		$this->registerTask( 'add', 			'edit' );
		$this->registerTask( 'apply', 			'save' );
		$this->registerTask( 'saveandnew', 		'save' );
	}

	/**
	 * Logic to save an item
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function save()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		jimport('joomla.filesystem.file');
		jimport('joomla.filesystem.archive');
		require_once (RESTAURANTGUIDE_ADMINISTRATOR.DS.'lib'.DS.'class.upload.php');
		
		global $rgconf;
		
		$task = JRequest::getVar('task');

		$post = JRequest::get( 'post' );
		$post['description'] = JRequest::getVar( 'description', '', 'post', 'string', JREQUEST_ALLOWRAW );

		$model = $this->getModel('galleryitem');
		$data = $model->getFile($post['id']);

		if ($post['resto'] > 0)
			$directory = 'restaurant_'.$post['resto'];
		else
			$directory = 'restaurant_0';
			
		if (isset($_FILES['file_upload'])){
		
			$handle = new Upload($_FILES['file_upload']);

			if ($handle->uploaded) {
				// Original image
				$dir =  RESTAURANTGUIDE_IMAGES_GALLERY.DS.$directory.DS.'album'.DS;
		
				if (!file_exists($dir)) {
					mkdir($dir, 0777);
				}

				$handle->jpeg_quality = 100;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$width = $handle->image_src_x;
				$height = $handle->image_src_y;
				$handle->file_new_name_body = $file_body;
				$handle->Process($dir);

				$post['filename'] = $handle->file_dst_name;	
				$post['imagewidth'] = $width;
				$post['imageheight'] = $height;
				
				// resized image
				$resize_dir =  RESTAURANTGUIDE_IMAGES_GALLERY.DS.$directory.DS.'resize'.DS;
	
				if (!file_exists($resize_dir)) {
					mkdir($resize_dir, 0777);
				}
		
				$handle->image_resize = true;
				if ($height < $width) {
					$handle->image_ratio_y = true;
					$handle->image_x = 240;//$imageWidth;
				} else {
					$handle->image_ratio_x = true;
					$handle->image_y = 240;//$imageHeight;
				}
				$handle->jpeg_quality = 85;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$handle->file_new_name_body = $file_body;

				$handle->Process($resize_dir);

				// thumbnail image
				$thumb_dir =  RESTAURANTGUIDE_IMAGES_GALLERY.DS.$directory.DS.'thumb'.DS;
	
				if (!file_exists($thumb_dir)) {
					mkdir($thumb_dir, 0777);
				}
		
				$handle->image_resize = true;
				$thumbwidth = $rgconf->gall_thumb_width;
				
				if (!$thumbwidth) 
					$thumbwidth = 86;
				if ($height < $width) {
					$handle->image_ratio_y = true;
					$handle->image_x = $thumbwidth;
				} else {
					$handle->image_ratio_x = true;
					$handle->image_y = $thumbwidth;
				}
				$handle->jpeg_quality = 100;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$handle->file_new_name_body = $file_body;
				
				$handle->Process($thumb_dir);
				
				$handle->Clean();
			}
		}
		
		if ( $model->store($post) ) {

			switch ($task)
			{
				case 'apply' :
					$link = 'index.php?option=com_restaurantguide&view=galleryitem&cid[]='.(int) $model->get('id');
					break;
					
				case 'saveandnew' :
					$link = 'index.php?option=com_restaurantguide&view=galleryitem';
					break;

				default :
					$link = 'index.php?option=com_restaurantguide&view=galleryitems';
					break;
			}
			$msg = JText::_( 'RG_ITEM_SAVED' );

			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();

		} else {
			$msg = JText::_( 'RG_ERROR_SAVING_ITEM' );
			JError::raiseError( 500, $model->getError() );
			$link 	= 'index.php?option=com_restaurantguide&view=galleryitem';
		}
		
		$model->checkin();
		
		$this->setRedirect($link, $msg);
	}

	function publish()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'RG_SELECT_ITEM_PUBLISH' ) );
		} else {

			$model = $this->getModel('galleryitems');

			if(!$model->publish($cid, 1)) {
				JError::raiseError(500, $model->getError());
			}

			$msg 	= JText::_( 'RG_GALLERY_IMAGE_PUBLISHED');
		
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=galleryitems', $msg );
	}

	/**
	 * Logic to unpublish event
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function unpublish()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'RG_SELECT_IMAGE_UNPUBLISH' ) );
		} else {

			$model = $this->getModel('galleryitems');

			if(!$model->publish($cid, 0)) {
				JError::raiseError(500, $model->getError());
			}

			$msg 	= JText::_( 'RG_GALLERY_IMAGE_UNPUBLISHED');
		
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=galleryitems', $msg );
	}
	
	/**
	 * Logic to orderup an item
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function orderup()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('galleryitems');
		$model->move(-1);

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=galleryitems');
	}

	/**
	 * Logic to orderdown an item
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function orderdown()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('galleryitems');
		$model->move(1);

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=galleryitems');
	}

	/**
	 * Logic to mass ordering items
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function saveorder()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$order 	= JRequest::getVar( 'order', array(0), 'post', 'array' );

		$model = $this->getModel('galleryitems');
		if(!$model->saveorder($cid, $order)) {
			$msg = '';
			JError::raiseError(500, $model->getError());
		} else {
			$msg = JText::_( 'RG_NEW_ORDERING_SAVED' );
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=galleryitems', $msg );
	}

	/**
	 * Logic to change the state
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function setitemstate()
	{
		$id 	= JRequest::getInt( 'id', 0 );
		$state 	= JRequest::getVar( 'state', 0 );

		$model = $this->getModel('galleryitems');

		if(!$model->setitemstate($id, $state)) {
			JError::raiseError(500, $model->getError());
		}

		if ( $state == 1 ) {
			$img = 'tick.png';
			$alt = JText::_( 'Published' );
		} else if ( $state == 0 ) {
			$img = 'publish_x.png';
			$alt = JText::_( 'Unpublished' );
		} 
		
		$cache = &JFactory::getCache('com_restaurantguide');
		$cache->clean();

		echo '<img src="images/'.$img.'" width="16" height="16" border="0" alt="'.$alt.'" />';
	}

	/**
	 * Logic to delete items
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function remove()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid = JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			JError::raiseError(500, JText::_( 'RG_SELECT_ITEM_DELETE' ) );
		}

		$model = $this->getModel('galleryitems');

		if(!$model->delete($cid)) {
			$msg = '';
			JError::raiseError(500, $model->getError());
		} else {
			$total 	= count( $cid );	  
			$msg 	= $total.' '.JText::_('RG_ITEMS_DELETED');

			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=galleryitems', $msg );
	}

	/**
	 * logic for cancel an action
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function cancel()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		$item = & JTable::getInstance('rg_galleryitems', '');
		$item->bind(JRequest::get('post'));
		$item->checkin();

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=galleryitems' );
	}

	/**
	 * Logic to create the view for the edit categoryscreen
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function edit( )
	{		
		JRequest::setVar( 'view', 'galleryitem' );
		JRequest::setVar( 'hidemainmenu', 1 );

		$model 	= $this->getModel('galleryitem');
		$user	=& JFactory::getUser();

		// Error if checkedout by another administrator
		if ($model->isCheckedOut( $user->get('id') )) {
			$this->setRedirect( 'index.php?option=com_restaurantguide&view=galleryitems', JText::_( 'RG_EDITED_BY_ANOTHER_ADMIN' ) );
		}

		$model->checkout( $user->get('id') );

		parent::display();
	}

	function removeFile($srcFilename, $srcFilePath) {
		$removeFilename = $srcFilePath . $srcFilename;
		if (unlink($removeFilename)) {
			return true;
		}
		else {
			return false;
		}
	}
}