<?php
/**
 * @version 1.0 $Id: restaurantguide_files.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');


/**
 * RestaurantGuide Component Reservation Controller
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since 1.0
 */
class restaurantguideControllerReservation extends restaurantguideController
{

	function __construct()
	{
		parent::__construct();

		// Register Extra task
		$this->registerTask( 'add', 'edit' );
		$this->registerTask( 'apply', 'save' );
	}

	/**
	 * Logic to save an item
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function save()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$task = JRequest::getVar('task');

		$post = JRequest::get( 'post' );
		$post['confirm_description'] = JRequest::getVar('confirm_description', '', 'POST', 'string', JREQUEST_ALLOWRAW);
		$post['change_description'] = JRequest::getVar('change_description', '', 'POST', 'string', JREQUEST_ALLOWRAW);
		$post['damount'] = $post['tamount'] - $post['pamount'];
		
		$model = $this->getModel('reservation');
	
		if ( $model->store($post) ) {

			switch ($task)
			{
				case 'apply' :
					$link = 'index.php?option=com_restaurantguide&view=reservation&cid[]='.(int) $model->get('id');
					break;

				default :
					$link = 'index.php?option=com_restaurantguide&view=reservations';
					break;
			}
			$msg = JText::_( 'RG_RESERVATION_SAVED' );

			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();

		} else {
			$msg = JText::_( 'RG_ERROR_SAVING_RESERVATION' );
			JError::raiseError( 500, $model->getError() );
			$link 	= 'index.php?option=com_restaurantguide&view=reservation';
		}
		
		$model->checkin();
		
		$this->setRedirect($link, $msg);
	}

	/**
	 * Logic to orderup an item
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function orderup()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('reservations');
		$model->move(-1);

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=reservations');
	}

	/**
	 * Logic to orderdown an item
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function orderdown()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('reservations');
		$model->move(1);

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=reservations');
	}

	/**
	 * Logic to mass ordering items
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function saveorder()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$order 	= JRequest::getVar( 'order', array(0), 'post', 'array' );

		$model = $this->getModel('reservations');
		if(!$model->saveorder($cid, $order)) {
			$msg = '';
			JError::raiseError(500, $model->getError());
		} else {
			$msg = JText::_( 'RG_NEW_ORDERING_SAVED' );
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=reservations', $msg );
	}

	/**
	 * Logic to delete items
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function remove()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid		= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			JError::raiseError(500, JText::_( 'RG_SELECT_ITEM_DELETE' ) );
		}

		$model = $this->getModel('reservations');

		if(!$model->delete($cid)) {
			$msg = '';
			JError::raiseError(500, $model->getError());
		} else {
			$total 	= count( $cid );
			$db 	=& JFactory::getDBO();

			for ($i = 0; $i < $total; $i++) {


			}

			$msg 	= $total.' '.JText::_($directory);

			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=reservations', $msg );
	}

	/**
	 * logic for cancel an action
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function cancel()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		$item = & JTable::getInstance('rg_reservations', '');
		$item->bind(JRequest::get('post'));
		$item->checkin();

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=reservations' );
	}

	/**
	 * Logic to create the view for the edit reservation
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function edit( )
	{		
		JRequest::setVar( 'view', 'reservation' );
		JRequest::setVar( 'hidemainmenu', 1 );

		$model 	= $this->getModel('reservation');
		$user	=& JFactory::getUser();

		// Error if checkedout by another administrator
		if ($model->isCheckedOut( $user->get('id') )) {
			$this->setRedirect( 'index.php?option=com_restaurantguide&view=reservations', JText::_( 'RG_EDITED_BY_ANOTHER_ADMIN' ) );
		}

		$model->checkout( $user->get('id') );

		parent::display();
	}
}