<?php
/**
 * @version 1.0 $Id: restaurantlinks.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RESTAURANTGUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');

/**
 * Restaurant Guide Component restaurantlinks Controller
 *
 * @package Joomla
 * @subpackage Restaurant Guide
 * @since 0.9
 */
class restaurantguideControllerRestaurantlinks extends restaurantguideController
{
	function __construct()
	{
		parent::__construct();

		// Register Extra tasks
		$this->registerTask( 'add'  ,		 	'edit' );
		$this->registerTask( 'apply', 			'save' );
		$this->registerTask( 'saveandnew', 		'save' );
		$this->registerTask( 'accesspublic', 	'access' );
		$this->registerTask( 'accessregistered','access' );
		$this->registerTask( 'accessspecial', 	'access' );
	}

	/**
	 * display the edit form
	 * @return void
	 */

	function edit()
	{
		JRequest::setVar( 'view', 'restaurantlinkedit' );
		JRequest::setVar( 'hidemainmenu', 1 );

		$model 	= $this->getModel('restaurantlinkedit');
		$user	=& JFactory::getUser();

		// Error if checkedout by another administrator
		if ($model->isCheckedOut( $user->get('id') )) {
			$this->setRedirect( 'index.php?option=com_restaurantguide&view=restaurantlinks', JText::_( 'RG_EDITED_BY_ANOTHER_ADMIN' ) );
		}

		$model->checkout( $user->get('id') );

		parent::display();
	}

	/**
	 * save a record (and redirect to main page)
	 * @return void
	 */

	function save()
	{
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$post	= JRequest::get('post');

		$model	=& $this->getModel('restaurantlinkedit');
		
		if ($model->store($post)) {
			switch ($task)
			{
				case 'apply' :
					$link = 'index.php?option=com_restaurantguide&view=restaurantlinkedit&cid[]='.(int) $model->get('id');
					break;
					
				case 'saveandnew' :
					$link = 'index.php?option=com_restaurantguide&view=restaurantlinkedit';
					break;

				default :
					$link = 'index.php?option=com_restaurantguide&view=restaurantlinks';
					break;
			}
			$msg = JText::_( 'RG_LINK_SAVED!' );
			
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		} else {
			$link 	= 'index.php?option=com_restaurantguide&view=restaurantlinks';
			$msg = JText::_( 'RG_ERROR_SAVING_LINK' );
		}

		$this->setRedirect($link, $msg);
	}

	function publish()
	{
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'RG_SELECT_ITEM_PUBLISH' ) );
		} else {
			$model = $this->getModel('restaurantlinks');

			if(!$model->publish($cid, 1)) {
				JError::raiseError( 500, $model->getError() );
			}

			$total = count( $cid );
			$msg 	= $total.' '.JText::_( 'RG_RESTAURANTLINK_PUBLISHED');
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=restaurantlinks', $msg );
	}
	
	function unpublish()
	{
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'RG_SELECT_ITEM_UNPUBLISH' ) );
		} else {
			$model = $this->getModel('restaurantlinks');

			if(!$model->publish($cid, 0)) {
				JError::raiseError( 500, $model->getError() );
			}

			$total = count( $cid );
			$msg 	= $total.' '.JText::_( 'RG_RESTAURANTLINK_UNPUBLISHED');
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=restaurantlinks', $msg );
	}

	/**
	 * remove record(s)
	 * @return void
	 */

	function remove()
	{
		$model = $this->getModel('restaurantlinkedit');

		if(!$model->delete()) {
			$msg = JText::_( 'RG_ERROR_ONE_OR_MORE_LINKS_COULD_NOT_BE_DELETED' );
		} else {
			$msg = JText::_( 'RG_LINK_DELETED' );
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=restaurantlinks', $msg );
	}

	/**
	 * cancel editing a record
	 * @return void
	 */

	function cancel()
	{
		$msg = JText::_( 'Operation Cancelled' );

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=restaurantlinks', $msg );
	}

}

?>

