<?php
/**
 * @version 1.0 $Id: restauranttypes.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');
jimport('joomla.filesystem.file');


/**
 * RestaurantGuide Component Restaurant Types Controller
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since 1.0
 */
class restaurantguideControllerRestaurantTypes extends restaurantguideController
{
	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		// Register Extra task
		$this->registerTask( 'add'  ,		 	'edit' );
		$this->registerTask( 'apply', 			'save' );
		$this->registerTask( 'saveandnew', 		'save' );
		$this->registerTask( 'accesspublic', 	'access' );
		$this->registerTask( 'accessregistered','access' );
		$this->registerTask( 'accessspecial', 	'access' );
	}

	/**
	 * Logic to save a type
	 *
	 * @access public
	 * @return void
	 * @since 1.5
	 */
	function save()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		jimport('joomla.filesystem.file');
		jimport('joomla.filesystem.archive');
		require_once (RESTAURANTGUIDE_ADMINISTRATOR.DS.'lib'.DS.'class.upload.php');
		
		$task		= JRequest::getVar('task');

		//Sanitize
		$post = JRequest::get( 'post' );

		$model = $this->getModel('restauranttype');

		if (isset($_FILES['file_upload'])){

			$handle = new Upload($_FILES['file_upload']);

			if ($handle->uploaded) {
				// Original image
				$dir =  RESTAURANTGUIDE_IMAGES_TYPE_ALBUM_URL;
		
				if (!file_exists($dir)) {
					mkdir($dir, 0777);
				}

				$handle->jpeg_quality = 100;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$width = $handle->image_src_x;
				$height = $handle->image_src_y;
				$handle->file_new_name_body = $file_body;
				$handle->Process($dir);

				$post['image'] = $handle->file_dst_name;	
				
				// resized image
				$resize_dir =  RESTAURANTGUIDE_IMAGES_TYPE_RESIZE_URL;
	
				if (!file_exists($resize_dir)) {
					mkdir($resize_dir, 0777);
				}
		
				$handle->image_resize = true;
				if ($height < $width) {
					$handle->image_ratio_y = true;
					if ($post['image_size'])
						$handle->image_x = $post['image_size'];
					else
						$handle->image_x = 160;
				} else {
					$handle->image_ratio_x = true;
					if ($post['image_size'])
						$handle->image_y = $post['image_size'];
					else
						$handle->image_y = 160;
				}
				$handle->jpeg_quality = 85;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$handle->file_new_name_body = $file_body;

				$handle->Process($resize_dir);

				$imagewidth = $handle->image_dst_x;
				$imageheight = $handle->image_dst_y;
				$post['imagewidth'] = $imagewidth;
				$post['imageheight'] = $imageheight;
				
				// thumbnail image
				$thumb_dir =  RESTAURANTGUIDE_IMAGES_TYPE_THUMB_URL;
	
				if (!file_exists($thumb_dir)) {
					mkdir($thumb_dir, 0777);
				}
		
				$handle->image_resize = true;
				if ($height < $width) {
					$handle->image_ratio_y = true;
					$handle->image_x = 74;
				} else {
					$handle->image_ratio_x = true;
					$handle->image_y = 74;
				}
				$handle->jpeg_quality = 85;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$handle->file_new_name_body = $file_body;
				
				$handle->Process($thumb_dir);
				
				$handle->Clean();
			}
		}
		
		if ( $model->store($post) ) {

			switch ($task)
			{
				case 'apply' :
					$link = 'index.php?option=com_restaurantguide&view=restauranttype&cid[]='.(int) $model->get('id');
					break;
					
				case 'saveandnew' :
					$link = 'index.php?option=com_restaurantguide&view=restauranttype';
					break;

				default :
					$link = 'index.php?option=com_restaurantguide&view=restauranttypes';
					break;
			}
			$msg = JText::_( 'RG_RESTAURANT_TYPE_SAVED' );

			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();

		} else {

			$msg = JText::_( 'RG_ERROR_SAVING_RESTAURANT_TYPE' );

			$link 	= 'index.php?option=com_restaurantguide&view=restauranttype';
		}

		$model->checkin();

		$this->setRedirect($link, $msg);
	}

	/**
	 * Logic to publish types
	 *
	 * @access public
	 * @return void
	 * @since 1.5
	 */
	function publish()
	{
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'RG_SELECT_RESTAURANT_TYPE_PUBLISH' ) );
		} else {
			$model = $this->getModel('restauranttypes');

			if(!$model->publish($cid, 1)) {
				JError::raiseError( 500, $model->getError() );
			}

			$total = count( $cid );
			$msg 	= $total.' '.JText::_( 'RG_RESTAURANT_TYPE_PUBLISH' );
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=restauranttypes', $msg );
	}

	/**
	 * Logic to unpublish types
	 *
	 * @access public
	 * @return void
	 * @since 1.5
	 */
	function unpublish()
	{
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$model 	= $this->getModel('restauranttypes');

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'RG_SELECT_ITEM_UNPUBLISH' ) );
		} else {

			if (!$model->publish($cid, 0)) {
				JError::raiseError(500, JText::_( 'RG_OPERATION_FAILED' ));
			}
			
			$msg = count($cid).' '.JText::_( 'RG_RESTAURANT_TYPE_UNPUBLISHED' );
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=restauranttypes', $msg );
	}

	/**
	 * Logic to delete types
	 *
	 * @access public
	 * @return void
	 * @since 1.5
	 */
	function remove()
	{
		$cid		= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$model 		= $this->getModel('restauranttypes');

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'RG_SELECT_ITEM_DELETE' ) );
		} else {

			if (!$model->delete($cid)) {
				JError::raiseError(500, JText::_( 'RG_OPERATION_FAILED' ));
			}
			
			$msg = count($cid).' '.JText::_( 'RG_RESTAURANT_TYPES_DELETED' );
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=restauranttypes', $msg );
	}

	/**
	 * logic for cancel an action
	 *
	 * @access public
	 * @return void
	 * @since 1.5
	 */
	function cancel()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		$type = & JTable::getInstance('rg_restauranttypes', '');
		$type->bind(JRequest::get('post'));
		$type->checkin();

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=restauranttypes' );
	}

	/**
	 * Logic to create the view for the edit type screen
	 *
	 * @access public
	 * @return void
	 * @since 1.5
	 */
	function edit( )
	{
		JRequest::setVar( 'view', 'restauranttype' );
		JRequest::setVar( 'hidemainmenu', 1 );

		$model 	= $this->getModel('restauranttype');
		$user	=& JFactory::getUser();

		// Error if checkedout by another administrator
		if ($model->isCheckedOut( $user->get('id') )) {
			$this->setRedirect( 'index.php?option=com_restaurantguide&view=restauranttypes', JText::_( 'RG_EDITED_BY_ANOTHER_ADMIN' ) );
		}

		$model->checkout( $user->get('id') );

		parent::display();
	}
	
	/**
	 * Logic to set the access level of the Types
	 *
	 * @access public
	 * @return void
	 * @since 1.5
	 */
	function access( )
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid		= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$id			= (int)$cid[0];
		$task		= JRequest::getVar( 'task' );

		if ($task == 'accesspublic') {
			$access = 0;
		} elseif ($task == 'accessregistered') {
			$access = 1;
		} else {
			$access = 2;
		}

		$model = $this->getModel('restauranttypes');
		
		if(!$model->access( $id, $access )) {
			JError::raiseError(500, $model->getError());
		} else {
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect('index.php?option=com_restaurantguide&view=restauranttypes' );
	}
}