<?php
/**
 * @version 1.0 $Id: settings.php
 * @package Joomla
 * @subpackage Restaurant Guide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENSE.php
 * Restaurant Guide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * Restaurant Guide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with Restaurant Guide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');

/**
 * Restaurant Guide Component Settings Controller
 *
 * @package Joomla
 * @subpackage Restaurant Guide
 * @since 1.0
 */
class RestaurantGuideControllerSettings extends restaurantguideController
{
	/**
	 * Constructor
	 *
	 * @access public
	 * @return void
	 * @since 0.9
	 */
	function __construct()
	{
		parent::__construct();

		// Register Extra task
		$this->registerTask( 'apply', 		'save' );
	}

	/**
	 * logic for cancel an action
	 *
	 * @access public
	 * @return void
	 * @since 0.9
	 */
	function cancel()
	{
		global $option;

		$model = $this->getModel('settings');

		$model->checkin();

		$this->setRedirect( 'index.php?option='.$option.'&view=restaurantguide' );
	}

	/**
	 * logic to create the edit venue view
	 *
	 * @access public
	 * @return void
	 * @since 0.9
	 */
	function edit( )
	{
		JRequest::setVar( 'view', 'settings' );

		parent::display();

		$model = $this->getModel('settings');

		$model->checkout();
	}

	/**
	 * saves the venue in the database
	 *
	 * @access public
	 * @return void
	 * @since 0.9
	 */
	function save()
	{
		// Check for request forgeries
		JRequest::checkToken() or die( 'Invalid Token' );

		jimport('joomla.filesystem.file');
		jimport('joomla.filesystem.archive');
		require_once (RESTAURANTGUIDE_ADMINISTRATOR.DS.'lib'.DS.'class.upload.php');
		
		// Sanitize
		$task	= JRequest::getVar('task');
		$post 	= JRequest::get( 'post' );
		$post['introdescription'] = JRequest::getVar('introdescription', '', 'POST', 'string', JREQUEST_ALLOWRAW);
		$post['conversionguide'] = JRequest::getVar('conversionguide', '', 'POST', 'string', JREQUEST_ALLOWRAW);
		$post['sponsor'] = JRequest::getVar('sponsor', '', 'POST', 'string', JREQUEST_ALLOWRAW);
		$post['registerintro'] = JRequest::getVar('registerintro', '', 'POST', 'string', JREQUEST_ALLOWRAW);

		//get model
		$model 	= $this->getModel('settings');

		if (isset($_FILES['file_upload'])){
			$handle = new Upload($_FILES['file_upload']);

			if ($handle->uploaded) {

				$dir =  RESTAURANTGUIDE_ASSETS_IMAGES.DS;
		
				if (!file_exists($dir)) {
					mkdir($dir, 0777);
				}

				$handle->image_resize = true;
				$handle->jpeg_quality = 100;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$handle->image_ratio_y = true;
				$handle->image_x = 160;
				$handle->file_new_name_body = 'logoimage';
				$handle->Process($dir);
				
				$imagewidth = $handle->image_dst_x;
				$imageheight = $handle->image_dst_y;
				$post['logowidth'] = $imagewidth;
				$post['logoheight'] = $imageheight;
				$post['logoimage'] = $handle->file_dst_name;	

				$handle->Clean();
			}
		}
		
		if (isset($_FILES['title_upload'])){

			$handle = new Upload($_FILES['title_upload']);

			if ($handle->uploaded) {
				// Original image
				$dir =  RESTAURANTGUIDE_IMAGES_COUNTRY_ALBUM_URL;
		
				if (!file_exists($dir)) {
					mkdir($dir, 0777);
				}

				$handle->jpeg_quality = 100;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$width = $handle->image_src_x;
				$height = $handle->image_src_y;
				$handle->file_new_name_body = $file_body;
				$handle->Process($dir);

				$post['titleimage'] = $handle->file_dst_name;	
				$post['titleimagewidth'] = $width;
				$post['titleimageheight'] = $height;
				
				// thumbnail image
				$thumb_dir =  RESTAURANTGUIDE_IMAGES_COUNTRY_THUMB_URL;
	
				if (!file_exists($thumb_dir)) {
					mkdir($thumb_dir, 0777);
				}
		
				$handle->image_resize = true;
				if ($height < $width) {
					$handle->image_ratio_y = true;
					$handle->image_x = 74;
				} else {
					$handle->image_ratio_x = true;
					$handle->image_y = 74;
				}
				$handle->jpeg_quality = 85;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$handle->file_new_name_body = $file_body;
				
				$handle->Process($thumb_dir);
				
				$handle->Clean();
			}
		}
		
		if (isset($_FILES['register_upload'])){
			$handle = new Upload($_FILES['register_upload']);

			if ($handle->uploaded) {

				$dir =  RESTAURANTGUIDE_IMAGES_GALLERY.DS;
		
				if (!file_exists($dir)) {
					mkdir($dir, 0777);
				}

				$handle->jpeg_quality = 100;
				$handle->file_auto_rename = false;
				$handle->file_overwrite = true;
				$width = $handle->image_src_x;
				$height = $handle->image_src_y;
				$handle->file_new_name_body = 'registerlogo';
				$handle->Process($dir);

				$post['registerlogowidth'] = $width;
				$post['registerlogoheight'] = $height;
				$post['registerlogo'] = $handle->file_dst_name;	

				$handle->Clean();
			}
		}
		
		if ($model->store($post)) {
			$msg	= JText::_( 'RG_SETTINGS_SAVE');
		} else {
			$msg	= JText::_( 'RG_SAVE_SETTINGS_FAILED');
		}

		switch ($task)
		{
			case 'apply':
				$link = 'index.php?option=com_restaurantguide&controller=settings&task=edit';
				break;

			default:
				$link = 'index.php?option=com_restaurantguide&view=restaurantguide';
				break;
		}
		$model->checkin();

		$this->setRedirect( $link, $msg );
	}
}
?>