<?php
/**
 * @version 1.0 $Id: testimonials.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RESTAURANTGUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');

/**
 * RestaurantGuide Testimonial Controller
 *
 * @package Joomla
 * @subpackage RestaurantGuide Testimonial
 * @since 1.0
 */
class restaurantguideControllerTestimonials extends restaurantguideController
{
	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		// Register Extra task
		$this->registerTask( 'add'  ,		 	'edit' );
		$this->registerTask( 'apply', 			'save' );
		$this->registerTask( 'accesspublic', 	'access' );
		$this->registerTask( 'accessregistered','access' );
		$this->registerTask( 'accessspecial', 	'access' );
	}

	/**
	 * Logic to save a testimonials
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function save()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$task		= JRequest::getVar('task');

		//Sanitize
		$post = JRequest::get( 'post' );
		$post['description'] = JRequest::getVar('description', '', 'POST', 'string', JREQUEST_ALLOWRAW);
		
		$model = $this->getModel('testimonialedit');
		
		if ( $model->store($post) ) {

			switch ($task)
			{
				case 'apply' :
					$link = 'index.php?option=com_restaurantguide&view=testimonialedit&cid[]='.(int) $model->get('id');
					break;

				default :
					$link = 'index.php?option=com_restaurantguide&view=testimonials';
					break;
			}
			$msg = JText::_( 'RG_REVIEW_SAVED' );
						
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		} else {
			$msg 	= JText::_( 'RG_ERROR_SAVING_REVIEW' );

			$link 	= 'index.php?option=com_restaurantguide&view=testimonialedit';
		}

		$this->setRedirect($link, $msg);
	}

	/**
	 * Logic to publish testimonials
	 *
	 * @access public
	 * @return void

	 * @since 1.0
	 */
	function publish()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'RG_SELECT_ITEM_PUBLISH' ) );
		} else {

			$model = $this->getModel('testimonials');

			if(!$model->publish($cid, 1)) {
				JError::raiseError(500, $model->getError());
			}

			$msg 	= JText::_( 'RG_REVIEW_PUBLISHED');
		
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=testimonials', $msg );
	}

	/**
	 * Logic to unpublish testimonials
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function unpublish()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'RG_SELECT_REVIEW_UNPUBLISH' ) );
		} else {

			$model = $this->getModel('testimonials');

			if(!$model->publish($cid, 0)) {
				JError::raiseError(500, $model->getError());
			}

			$msg 	= JText::_( 'RG_REVIEW_UNPUBLISHED');
		
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=testimonials', $msg );
	}

	/**
	 * Logic to orderup a testimonials
	 *
	 * @access public
	 * @return void;
	 * @since 1.0
	 */
	function orderup()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('testimonials');
		$model->move(-1);
		
		$cache = &JFactory::getCache('com_restaurantguide');
		$cache->clean();
		
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=testimonials');
	}

	/**
	 * Logic to orderdown a testimonials
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function orderdown()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('testimonials');
		$model->move(1);
		
		$cache = &JFactory::getCache('com_restaurantguide');
		$cache->clean();

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=testimonials');
	}

	/**
	 * Logic to mass ordering testimonials
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function saveorder()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$order 	= JRequest::getVar( 'order', array(0), 'post', 'array' );

		$model = $this->getModel('testimonials');
		if(!$model->saveorder($cid, $order)) {
			$msg = '';
			JError::raiseWarning(500, $model->getError());
		}
		
		$cache = &JFactory::getCache('com_restaurantguide');
		$cache->clean();

		$msg = 'RG_NEW_ORDERING_SAVED';
		$this->setRedirect( 'index.php?option=com_restaurantguide&view=testimonials', $msg );
	}

	/**
	 * Logic to delete testimonials
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function remove()
	{
		$cid = JRequest::getVar( 'cid', array(0), 'post', 'array' );

		$total = count( $cid );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			JError::raiseError(500, JText::_( 'Select an item to delete' ) );
		}

		$model = $this->getModel('testimonials');
		if(!$model->delete($cid)) {
			echo "<script> alert('".$model->getError(true)."'); window.history.go(-1); </script>\n";
		}

		$msg = $total.' '.JText::_( 'RG_REVIEW_DELETED');

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=testimonials', $msg );
	}

	/**
	 * logic for cancel an action
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function cancel()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$testimonials = & JTable::getInstance('rg_testimonial', '');
		$testimonials->bind(JRequest::get('post'));
		$testimonials->checkin();

		$this->setRedirect( 'index.php?option=com_restaurantguide&view=testimonials' );
	}

	/**
	 * Logic to set the testimonials access level
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function access( )
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid		= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$id			= (int)$cid[0];
		$task		= JRequest::getVar( 'task' );

		if ($task == 'accesspublic') {
			$access = 0;
		} elseif ($task == 'accessregistered') {
			$access = 1;
		} else {
			$access = 2;
		}

		$model = $this->getModel('testimonials');
		
		if(!$model->access( $id, $access )) {
			JError::raiseError(500, $model->getError());
		} else {
			$cache = &JFactory::getCache('com_restaurantguide');
			$cache->clean();
		}
		
		$this->setRedirect('index.php?option=com_restaurantguide&view=testimonials' );
	}

	/**
	 * Logic to create the view for the edit testimonials
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function edit( )
	{	
		JRequest::setVar( 'view', 'testimonialedit' );
		JRequest::setVar( 'hidemainmenu', 1 );

		$model 	= $this->getModel('testimonialedit');
		$user	=& JFactory::getUser();
		
		parent::display();
	}
}