<?php
/**
 * @version 1.0 $Id: city.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component city Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelCity extends JModel
{
	/**
	 * Type data
	 *
	 * @var object
	 */
	var $_city = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	/**
	 * Method to set the identifier
	 *
	 * @access	public
	 * @param	int type identifier
	 */
	function setId($id)
	{
		// Set type id and wipe data
		$this->_id	    = $id;
		$this->_city	= null;
	}
	
	/**
	 * Overridden get method to get properties from the type
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.0
	 */
	function get($property, $default=null)
	{
		if ($this->_loadCity()) {
			if(isset($this->_city->$property)) {
				return $this->_city->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to get type data
	 *
	 * @access	public
	 * @return	array
	 * @since	1.0
	 */
	function &getCity()
	{
		if ($this->_loadCity())
		{
		}
		else  $this->_initCity();
		
		return $this->_city;
	}


	/**
	 * Method to load city data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _loadCity()
	{
		// Lets load the type if it doesn't already exist
		if (empty($this->_city))
		{
			$query = 'SELECT *'
					. ' FROM #__rg_cities'
					. ' WHERE id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_city = $this->_db->loadObject();

			return (boolean) $this->_city;
		}
		return true;
	}

	/**
	 * Method to initialise the city data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _initCity()
	{
		// Lets load the city if it doesn't already exist
		if (empty($this->_city))
		{
			$city = new stdClass();
			$city->id					= 0;
			$city->parent_id			= 0;
			$city->name					= null;
			$city->alias				= null;
			$city->states				= 0;
			$city->country				= 0;
			$city->published			= 1;
			$city->destination			= 0;
			$city->description			= null;
			$city->image				= null;
			$city->imagewidth			= 0;
			$city->imageheight			= 0;
			$city->titleimage			= null;
			$city->titleimagewidth		= 0;
			$city->titleimageheight		= 0;
			$city->lat					= 0;
			$city->lon					= 0;
			$city->meta_title			= null;
			$city->meta_description		= null;
			$city->meta_keywords		= null;
			$this->_city				= $city;
			return (boolean) $this->_city;
		}
		return true;
	}

	/**
	 * Method to checkin/unlock the type
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$city = & JTable::getInstance('rg_cities', '');
			return $city->checkout($uid, $this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the type
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the group with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$city = & JTable::getInstance('rg_cities', '');
			return $city->checkout($uid, $this->_id);
		}
		return false;
	}

	/**
	 * Tests if the type is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadCity())
		{
			if ($uid) {
				return ($this->_city->checked_out && $this->_city->checked_out != $uid);
			} else {
				return $this->_city->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}

	/**
	 * Method to store the type
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function store($data)
	{
		$city  =& $this->getTable('rg_cities', '');
		
		$tags 		= JRequest::getVar( 'tag', array(), 'post', 'array');

		// bind it to the table
		if (!$city->bind($data)) {
			$this->setError( $this->_db->getErrorMsg() );
			return false;
		}

		// Make sure the data is valid
		if (!$city->check()) {
			$this->setError($city->getError() );
			return false;
		}

		// Store it in the db
		if (!$city->store()) {
			$this->setError( $this->_db->getErrorMsg() );
			return false;
		}
		
		$this->_city	=& $city;

		//store tag relation
		$query = 'DELETE FROM #__rg_tags_item_relations WHERE city = '.$city->id;
		$this->_db->setQuery($query);
		$this->_db->query();
			
		foreach($tags as $tag)
		{
			$query = 'INSERT INTO #__rg_tags_item_relations (`tid`, `city`) VALUES(' . $tag . ',' . $city->id . ')';
			$this->_db->setQuery($query);
			$this->_db->query();
		}
		
		return true;
	}
	
	function gettags($type)
	{
		$query = 'SELECT * FROM #__rg_tags WHERE type = '.$type.' ORDER BY name';
		$this->_db->setQuery($query);
		$tags = $this->_db->loadObjectlist();
		return $tags;
	}
	
	/**
	 * Method to fetch used tags when performing an edit action
	 * 
	 * @param int id
	 * @return array
	 * @since 1.0
	 */
	function getusedtags($id)
	{
		$query = 'SELECT DISTINCT tid FROM #__rg_tags_item_relations WHERE city = ' . (int)$id;
		$this->_db->setQuery($query);
		$used = $this->_db->loadResultArray();
		return $used;
	}
	
	function addCity($name, $country){
		
		$obj = new stdClass();
		$obj->name		= $name;
		$obj->country	= $country;
		$obj->published	= 1;
		
		$this->store($obj);
		
		return true;
	}
}
?>