<?php
/**
 * @version 1.0 $Id: continent.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component Continent Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelContinent extends JModel
{
	/**
	 * Type data
	 *
	 * @var object
	 */
	var $_continent = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	/**
	 * Method to set the identifier
	 *
	 * @access	public
	 * @param	int type identifier
	 */
	function setId($id)
	{
		// Set type id and wipe data
		$this->_id	    = $id;
		$this->_continent	= null;
	}
	
	/**
	 * Overridden get method to get properties from the type
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.0
	 */
	function get($property, $default=null)
	{
		if ($this->_loadContinent()) {
			if(isset($this->_continent->$property)) {
				return $this->_continent->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to get type data
	 *
	 * @access	public
	 * @return	array
	 * @since	1.0
	 */
	function &getContinent()
	{
		if ($this->_loadContinent())
		{
		}
		else  $this->_initContinent();
	
		return $this->_continent;
	}


	/**
	 * Method to load Continent data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _loadContinent()
	{
		// Lets load the type if it doesn't already exist
		if (empty($this->_continent))
		{
			$query = 'SELECT *'
					. ' FROM #__rg_continents'
					. ' WHERE id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_continent = $this->_db->loadObject();

			return (boolean) $this->_continent;
		}
		return true;
	}

	/**
	 * Method to initialise the Continent data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _initContinent()
	{
		// Lets load the continent if it doesn't already exist
		if (empty($this->_continent))
		{
			$continent = new stdClass();
			$continent->id					= 0;
			$continent->name				= null;
			$continent->alias				= null;
			$continent->published			= 1;
			$continent->image				= null;
			$continent->imagewidth			= 0;
			$continent->imageheight			= 0;
			$continent->titleimage			= null;
			$continent->titleimagewidth		= 0;
			$continent->titleimageheight	= 0;
			$continent->description			= null;
			$continent->meta_title			= null;
			$continent->meta_description	= null;
			$continent->meta_keywords		= null;
			$continent->lat					= 0;
			$continent->lon					= 0;
			$continent->zoom				= 6;
			$continent->maptype				= 'map';
			$continent->mapheight			= 400;
			$this->_continent				= $continent;
			return (boolean) $this->_continent;
		}
		return true;
	}

	/**
	 * Method to checkin/unlock the type
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$continent = & JTable::getInstance('rg_continents', '');
			return $continent->checkout($uid, $this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the type
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the group with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$continent = & JTable::getInstance('rg_continents', '');
			return $continent->checkout($uid, $this->_id);
		}
		return false;
	}

	/**
	 * Tests if the type is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadContinent())
		{
			if ($uid) {
				return ($this->_continent->checked_out && $this->_continent->checked_out != $uid);
			} else {
				return $this->_continent->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}

	/**
	 * Method to store the type
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function store($data)
	{
		$continent  =& $this->getTable('rg_continents', '');

		// bind it to the table
		if (!$continent->bind($data)) {
			$this->setError( $this->_db->getErrorMsg() );
			return false;
		}

		// Make sure the data is valid
		if (!$continent->check()) {
			$this->setError($continent->getError() );
			return false;
		}

		// Store it in the db
		if (!$continent->store()) {
			$this->setError( $this->_db->getErrorMsg() );
			return false;
		}
		
		$this->_continent	=& $continent;

		return true;
	}
	
	function addContinent($name, $continent){
		
		$obj = new stdClass();
		$obj->name		= $name;
//		$obj->country	= $country;
		$obj->published	= 1;
		
		$this->store($obj);
		
		return true;
	}
}
?>