<?php
/**
 * @version 1.0 $Id: menu.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RESTAURANTGUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component Menu Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelMenu extends JModel
{
	/**
	 * Menu data
	 *
	 * @var object
	 */
	var $_menu = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	/**
	 * Method to set the identifier
	 *
	 * @access	public
	 * @param	int menu identifier
	 */
	function setId($id)
	{
		// Set category id and wipe data
		$this->_id	    = $id;
		$this->_menu	= null;
	}
	
	/**
	 * Overridden get method to get properties from the menu
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.0
	 */
	function get($property, $default=null)
	{
		if ($this->_loadMenu()) {
			if(isset($this->_menu->$property)) {
				return $this->_menu->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to get menu data
	 *
	 * @access	public
	 * @return	array
	 * @since	1.0
	 */
	function &getMenu()
	{
		if ($this->_loadMenu())
		{

		}
		else  $this->_initMenu();

		return $this->_menu;
	}

	/**
	 * Method to load menu data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _loadMenu()
	{
		// Lets load the category if it doesn't already exist
		if (empty($this->_menu))
		{
			$query = 'SELECT m.*, c.code AS currency'
					. ' FROM #__rg_menus AS m'
					. ' LEFT JOIN #__rg_restaurantitems AS r ON r.id = m.resto'
					. ' LEFT JOIN #__rg_currency AS c ON c.id = r.currency'
					. ' WHERE m.id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_menu = $this->_db->loadObject();

			return (boolean) $this->_menu;
		}
		return true;
	}

	/**
	 * Method to initialise the menu data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _initMenu()
	{
		// Lets load the menu if it doesn't already exist
		if (empty($this->_menu))
		{
			$menu = new stdClass();
			$menu->id					= 0;
			$menu->parent_id			= 0;
			$menu->country				= 0;
			$menu->states				= 0;
			$menu->city					= 0;
			$menu->resto				= 0;
			$menu->title				= null;
			$menu->alias				= null;
			$menu->description			= null;
			$menu->published			= 1;
			$menu->image				= null;
			$menu->imagewidth			= 0;
			$menu->imageheight			= 0;
			$menu->backimage			= null;
			$menu->backimagewidth		= 0;
			$menu->backimageheight		= 0;
			$menu->transparency			= 0;
			$menu->price				= null;
			$menu->access				= 0;
			$menu->currency				= 0;
			$this->_menu				= $menu;
			return (boolean) $this->_menu;
		}
		return true;
	}

	/**
	 * Method to checkin/unlock the menu
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$menu = & JTable::getInstance('rg_menus', '');
			return $menu->checkin($this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the menu
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the menu with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$menu = & JTable::getInstance('rg_menus', '');
			if(!$menu->checkout($uid, $this->_id)) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}

			return true;
		}
		return false;
	}

	/**
	 * Tests if the menu is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadMenu())
		{
			if ($uid) {
				return ($this->_menu->checked_out && $this->_menu->checked_out != $uid);
			} else {
				return $this->_menu->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}

	/**
	 * Method to store the menu
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function store($data)
	{
		$menu  =& $this->getTable('rg_menus', '');

		// bind it to the table
		if (!$menu->bind($data)) {
			$this->setError(500, $this->_db->getErrorMsg() );
			return false;
		}

		if (!$menu->id) {
			$menu->ordering = $menu->getNextOrder();
		}
		
		// Make sure the data is valid
		if (!$menu->check()) {
			$this->setError($menu->getError());
			return false;
		}

		// Store it in the db
		if (!$menu->store()) {
			$this->setError(500, $this->_db->getErrorMsg() );
			return false;
		}
		
		$this->_menu	=& $menu;
		
		return true;
	}
	
	function getCurrency()
	{
		if ($this->_menu) {
			$query = 'SELECT currency'
					. ' FROM #__rg_restaurantitems'
					. ' WHERE id = '.$this->_menu->resto
					;
			$this->_db->setQuery($query);
			$result = $this->_db->loadObject();
		} else {
			$result = 0;
		}
		
		return $result;
	}
	
	function getFile($id)
	{
		$query = 'SELECT image'
				. ' FROM #__rg_menus'
				. ' WHERE id = '.$id
				;
		$this->_db->setQuery($query);
		$file = $this->_db->loadObject();
		
		return $file;
	}
}
?>