<?php
/**
 * @version 1.0 $Id: promotions.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component Promotions Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelPromotions extends JModel
{
	var $_app = null;
	
	/**
	 * Items data
	 *
	 * @var object
	 */
	var $_data = null;

	/**
	 * Items total
	 *
	 * @var integer
	 */
	var $_total = null;

	/**
	 * Pagination object
	 *
	 * @var object
	 */
	var $_pagination = null;

	/**
	 * Item id
	 *
	 * @var int
	 */
	var $_id = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$this->_app = &JFactory::getApplication();

		$limit		= $this->_app->getUserStateFromRequest( RG_OPTION.'.limit', 'limit', $this->_app->getCfg('list_limit'), 'int');
		$limitstart = $this->_app->getUserStateFromRequest( RG_OPTION.'.limitstart', 'limitstart', 0, 'int' );

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	/**
	 * Method to set the Items identifier
	 *
	 * @access	public
	 * @param	int Category identifier
	 */
	function setId($id)
	{
		// Set id and wipe data
		$this->_id	 = $id;
		$this->_data = null;
	}

	/**
	 * Method to get item data
	 *
	 * @access public
	 * @return object
	 */
	function getData()
	{
		// Lets load the Items if it doesn't already exist
		if (empty($this->_data))
		{
			$query = $this->_buildQuery();
			$this->_data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));
		}
		
		return $this->_data;
	}

	/**
	 * Method to get the total nr of the Items
	 *
	 * @access public
	 * @return integer
	 */
	function getTotal()
	{
		// Lets load the Items if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);
		}

		return $this->_total;
	}

	/**
	 * Method to get a pagination object for the Items
	 *
	 * @access public
	 * @return object
	 */
	function getPagination()
	{
		// Lets load the Items if it doesn't already exist
		if (empty($this->_pagination))
		{
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination( $this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}

		return $this->_pagination;
	}

	/**
	 * Method to build the query for the Items
	 *
	 * @access private
	 * @return string
	 * @since 1.0
	 */
	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildContentWhere();
		$orderby	= $this->_buildContentOrderBy();

		$query = 'SELECT DISTINCT i.*, h.title AS restoname'
				. ' FROM #__rg_promotions AS i'
				. ' LEFT JOIN #__rg_restaurantitems AS h ON h.id = i.resto'
				. $where
				. $orderby
				;

		return $query;
	}

	/**
	 * Method to build the orderby clause of the query for the Items
	 *
	 * @access private
	 * @return string
	 * @since 1.0
	 */
	function _buildContentOrderBy()
	{
		$filter_order		= $this->_app->getUserStateFromRequest( RG_OPTION.'.promotions.filter_order', 'filter_order', 'i.ordering', 'cmd' );
		$filter_order_Dir	= $this->_app->getUserStateFromRequest( RG_OPTION.'.promotions.filter_order_Dir', 'filter_order_Dir', '', 'word' );

		$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_Dir.', i.ordering';

		return $orderby;
	}

	/**
	 * Method to build the where clause of the query for the Items
	 *
	 * @access private
	 * @return string
	 * @since 1.0
	 */
	function _buildContentWhere()
	{
		$filter_resto 	= $this->_app->getUserStateFromRequest( RG_OPTION.'.promotions.filter_resto', 'filter_resto', 0, 'int');
		$filter_state 	= $this->_app->getUserStateFromRequest( RG_OPTION.'.promotions.filter_state', 'filter_state', '', 'word' );
		$search 		= $this->_app->getUserStateFromRequest( RG_OPTION.'.promotions.search', 'search', '', 'string' );
		$search 		= $this->_db->getEscaped( trim(JString::strtolower( $search ) ) );

		$where = array();
		
		$where[] = ' i.published != -1';
		
		if ($filter_resto > 0) {
			$where[] = ' i.resto = '.$filter_resto ;
		}

		if ($search) {
			$where[] = ' LOWER(i.title) LIKE '.$this->_db->Quote( '%'.$this->_db->getEscaped( $search, true ).'%', false );
		}

		$where 		= ( count( $where ) ? ' WHERE ' . implode( ' AND ', $where ) : '' );
		
		return $where;
	}

	/**
	 * Method to change the state of an item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function setitemstate($id, $state = 1)
	{
		$user 	=& JFactory::getUser();

		if ( $id )
		{
			$query = 'UPDATE #__rg_promotions'
				. ' SET published = ' . (int)$state
				. ' WHERE id = '.(int)$id
				. ' AND ( checked_out = 0 OR ( checked_out = ' . (int) $user->get('id'). ' ) )'
			;
			$this->_db->setQuery( $query );
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}
		return true;
	}

	function publish($cid = array(), $publish = 1)
	{
		$user 	=& JFactory::getUser();

		if (count( $cid ))
		{
			$cids = implode( ',', $cid );

			$query = 'UPDATE #__rg_promotions'
				. ' SET published = ' . (int) $publish
				. ' WHERE id IN ('. $cids .')'
				. ' AND ( checked_out = 0 OR ( checked_out = ' . (int) $user->get('id'). ' ) )'
			;
			$this->_db->setQuery( $query );
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}
		return true;
	}
	
	/**
	 * Method to move a Item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function move($direction)
	{
		$row =& JTable::getInstance('rg_promotions', '');

		if (!$row->load( $this->_id ) ) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		if (!$row->move( $direction )) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		return true;
	}

	/**
	 * Method to order Items
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function saveorder($cid = array(), $order)
	{
		$row =& JTable::getInstance('rg_promotions', '');
		
		// update ordering values
		for( $i=0; $i < count($cid); $i++ )
		{
			$row->load( (int) $cid[$i] );

			if ($row->ordering != $order[$i])
			{
				$row->ordering = $order[$i];
				if (!$row->store()) {
					$this->setError($this->_db->getErrorMsg());
					return false;
				}
			}
		}

		return true;
	}

	/**
	 * Method to remove a gallery item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function delete($cid)
	{
		$total 	= count( $cid );
				
		if (count( $cid ))
		{
			for ($i = 0; $i < $total; $i++) {
				$query = 'SELECT * FROM #__rg_promotions'
						. ' WHERE id = ' . $cid[$i]
						;
	
				$this->_db->setQuery( $query );
				$result = $this->_db->loadObject();
				
				$directory = 'restaurant_'.$result->resto;

				if (JFile::exists(RESTAURANTGUIDE_IMAGES_GALLERY.DS.$directory.DS.'album'.DS.$result->filename)) {
					JFile::delete(RESTAURANTGUIDE_IMAGES_GALLERY.DS.$directory.DS.'album'.DS.$result->filename);
				}

				if (JFile::exists(RESTAURANTGUIDE_IMAGES_GALLERY.DS.$directory.DS.'resize'.DS.$result->filename)) {
					JFile::delete(RESTAURANTGUIDE_IMAGES_GALLERY.DS.$directory.DS.'resize'.DS.$result->filename);
				}
				
				if (JFile::exists(RESTAURANTGUIDE_IMAGES_GALLERY.DS.$directory.DS.'thumb'.DS.$result->filename)) {
					JFile::delete(RESTAURANTGUIDE_IMAGES_GALLERY.DS.$directory.DS.'thumb'.DS.$result->filename);
				}
			}
				
			$cids = implode( ',', $cid );
			$query = 'DELETE FROM #__rg_promotions'
					. ' WHERE id IN ('. $cids .')'
					;

			$this->_db->setQuery( $query );
			
			if(!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
	
			return true;
		}
		return false;
	}
	
	function removeFile($file) {
		if (unlink($file)) {
			return true;
		}
		else {
			return false;
		}
	}
	
	function getRestos()
	{
		$query = 'SELECT DISTINCT r.id, r.title'
				. ' FROM #__rg_promotions AS p'
				. ' LEFT JOIN #__rg_restaurantitems AS r ON r.id = p.resto'
				. ' WHERE r.published = 1'
				. ' ORDER BY r.title'
				;
				
		$this->_db->setQuery($query);
		$restos = $this->_db->loadObjectList();
		
		return $restos;
	}
}
?>