<?php
/**
 * @version 1.0 $Id: recipe.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component Recipe Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelRecipe extends JModel
{
	/**
	 * Cuisine data
	 *
	 * @var object
	 */
	var $_recipe = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	/**
	 * Method to set the identifier
	 *
	 * @access	public
	 * @param	int category identifier
	 */
	function setId($id)
	{
		// Set category id and wipe data
		$this->_id	    	= $id;
		$this->_recipe	= null;
	}
	
	/**
	 * Overridden get method to get properties from the category
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.0
	 */
	function get($property, $default=null)
	{
		if ($this->_loadRecipe()) {
			if(isset($this->_recipe->$property)) {
				return $this->_recipe->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to get category data
	 *
	 * @access	public
	 * @return	array
	 * @since	1.0
	 */
	function &getRecipe()
	{
		if ($this->_loadRecipe())
		{

		}
		else  $this->_initRecipe();

		return $this->_recipe;
	}

	/**
	 * Method to load category data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _loadRecipe()
	{
		// Lets load the category if it doesn't already exist
		if (empty($this->_recipe))
		{
			$query = 'SELECT *'
					. ' FROM #__rg_recipes'
					. ' WHERE id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_recipe = $this->_db->loadObject();

			return (boolean) $this->_recipe;
		}
		return true;
	}

	/**
	 * Method to initialise the category data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _initRecipe()
	{
		// Lets load the category if it doesn't already exist
		if (empty($this->_recipe))
		{
			$recipe = new stdClass();
			$recipe->id					= 0;
			$recipe->parent_id			= 0;
			$recipe->title				= null;
			$recipe->alias				= null;
			$recipe->description		= null;
			$recipe->ingredients		= null;
			$recipe->methods			= null;
			$recipe->meta_keywords		= null;
			$recipe->meta_description	= null;
			$recipe->published			= 1;
			$recipe->hits				= 0;
			$recipe->image				= '';
			$recipe->imagewidth			= '';
			$recipe->imageheight		= '';
			$recipe->access				= 0;
			$this->_recipe				= $recipe;
			return (boolean) $this->_recipe;
		}
		return true;
	}

	/**
	 * Method to checkin/unlock the category
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$recipe = & JTable::getInstance('rg_recipes', '');
			return $recipe->checkin($this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the category
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the category with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$recipe = & JTable::getInstance('rg_recipes', '');
			if(!$recipe->checkout($uid, $this->_id)) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}

			return true;
		}
		return false;
	}

	/**
	 * Tests if the category is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadRecipe())
		{
			if ($uid) {
				return ($this->_recipe->checked_out && $this->_recipe->checked_out != $uid);
			} else {
				return $this->_recipe->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}

	/**
	 * Method to store the category
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function store($data)
	{
		$recipe  =& $this->getTable('rg_recipes', '');

		$tags 		= JRequest::getVar( 'tag', array(), 'post', 'array');
		
		// bind it to the table
		if (!$recipe->bind($data)) {
			$this->setError(500, $this->_db->getErrorMsg() );
			return false;
		}

		if (!$recipe->id) {
			$recipe->ordering = $recipe->getNextOrder();
		}
		
		// Make sure the data is valid
		if (!$recipe->check()) {
			$this->setError($recipe->getError());
			return false;
		}

		// Store it in the db
		if (!$recipe->store()) {
			$this->setError(500, $this->_db->getErrorMsg() );
			return false;
		}
		
		$this->_recipe	=& $recipe;
		
		//store tag relation
		$query = 'DELETE FROM #__rg_tags_item_relations WHERE recipe = '.$recipe->id;
		$this->_db->setQuery($query);
		$this->_db->query();
			
		foreach($tags as $tag)
		{
			$query = 'INSERT INTO #__rg_tags_item_relations (`tid`, `recipe`) VALUES(' . $tag . ',' . $recipe->id . ')';
			$this->_db->setQuery($query);
			$this->_db->query();
		}
		
		return true;
	}
	
	function gettags($type)
	{
		$query = 'SELECT * FROM #__rg_tags WHERE type = '.$type.' ORDER BY name';
		$this->_db->setQuery($query);
		$tags = $this->_db->loadObjectlist();
		return $tags;
	}
	
	/**
	 * Method to fetch used tags when performing an edit action
	 * 
	 * @param int id
	 * @return array
	 * @since 1.0
	 */
	function getusedtags($id)
	{
		$query = 'SELECT DISTINCT tid FROM #__rg_tags_item_relations WHERE recipe = ' . (int)$id;
		$this->_db->setQuery($query);
		$used = $this->_db->loadResultArray();
		return $used;
	}
	
	function getFile($id)
	{
		$query = 'SELECT image'
				. ' FROM #__rg_recipes'
				. ' WHERE id = '.$id
				;
		$this->_db->setQuery($query);
		$file = $this->_db->loadObject();
		
		return $file;
	}
}
?>