<?php
/**
 * @version 1.0 $Id: restaurantguide_files.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component Reservation Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelReservation extends JModel
{
	/**
	 * Item data
	 *
	 * @var object
	 */
	var $_item = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$cid = JRequest::getVar( 'cid', array(0), '', 'array' );
		JArrayHelper::toInteger($cid, array(0));
		$this->setId($cid[0]);
	}

	/**
	 * Method to set the identifier
	 *
	 * @access	public
	 * @param	int item identifier
	 */
	function setId($id)
	{
		// Set item id and wipe data
		$this->_id	    = $id;
		$this->_item	= null;
	}
	
	/**
	 * Overridden get method to get properties from the item
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.0
	 */
	function get($property, $default=null)
	{
		if ($this->_loadItem()) {
			if(isset($this->_item->$property)) {
				return $this->_item->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to get item data
	 *
	 * @access	public
	 * @return	array
	 * @since	1.0
	 */
	function &getItem()
	{		
		if ($this->_loadItem())
		{		

		}
		else  $this->_initItem();

		return $this->_item;
	}


	/**
	 * Method to load item data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _loadItem()
	{
		// Lets load the item if it doesn't already exist
		if (empty($this->_item))
		{
			$query = 'SELECT r.*, h.title AS restaurantname, c.name AS cityname, o.title AS roomtitle, t.bedtype AS bedname, t.breakfast'
					. ' FROM #__rg_reservations AS r'
					. ' LEFT JOIN #__rg_restaurantitems AS h ON h.id = r.restaurant'
					. ' LEFT JOIN #__rg_cities AS c ON c.id = r.city'
					. ' LEFT JOIN #__rg_roomitems AS o ON o.id = r.roomtype'
					. ' LEFT JOIN #__rg_roomrates AS t ON t.id = r.bedtype'
					. ' WHERE r.id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_item = $this->_db->loadObject();
			
			if ($this->_item->status == 0) {
				$query = 'UPDATE #__rg_reservations SET status = 2 WHERE id = '.$this->_id;
				$this->_db->setQuery($query);
				$this->_db->query();
			}
			
			return (boolean) $this->_item;
		}
		return true;
	}

	/**
	 * Method to initialise the item data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _initItem()
	{
		// Lets load the item if it doesn't already exist
		if (empty($this->_item))
		{
			$item = new stdClass();
			$item->id					= 0;
			$item->status				= 0;
			$item->ordering 			= null;
			$item->published			= 1;

			$this->_item				= $item;
			return (boolean) $this->_item;
		}
		return true;
	}

	/**
	 * Method to checkin/unlock the item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$item = & JTable::getInstance('rg_reservations', '');
			return $item->checkin($this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the item
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the group with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$item = & JTable::getInstance('rg_reservations', '');
			return $item->checkout($uid, $this->_id);
		}
		return false;
	}

	/**
	 * Tests if the item is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadItem())
		{
			if ($uid) {
				return ($this->_item->checked_out && $this->_item->checked_out != $uid);
			} else {
				return $this->_item->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}

	/**
	 * Method to store the item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function store($data)
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		JTable::addIncludePath(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_restaurantguide'.DS.'tables');
		$item =& JTable::getInstance('rg_reservations', '');

		$user	=& JFactory::getUser();
		$data->user_id	= $user->get('id');
		
		// bind it to the table
		if (!$item->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// sanitise id field
		$item->id = (int) $item->id;
		
		$nullDate	= $this->_db->getNullDate();
		
		// Are we saving from an item edit?
		if ($item->id) {
			$item->mdate 	= gmdate('Y-m-d H:i:s');
		} else {
			$item->mdate 	= $nullDate;
		}
		
		if (!$item->id) {
			$item->ordering = $item->getNextOrder();
		}
/*		
		// Make sure the data is valid
		if (!$item->check()) {
			$this->setError($item->getError());
			return false;
		}
*/
		// Store it in the db
		if (!$item->store()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		
		$this->_item =& $item; 

		return true;
	}
	
	function getRate($rateid)
	{
		$query = 'SELECT DISTINCT r.*'
				. ' FROM #__rg_roomrates AS r'
				. ' WHERE r.id = '.(int)$rateid
				;
				
		$this->_db->setQuery( $query );
		$rate = $this->_db->loadObject();
		
		return $rate;
	}
	
	function getRooms($restaurant)
	{
		$query = 'SELECT DISTINCT r.*'
				. ' FROM #__rg_roomitems AS r'
				. ' LEFT JOIN #__rg_restaurantitems AS h ON h.id = r.restaurant'
				. ' LEFT JOIN #__rg_roomrates AS ri ON ri.room_id = r.id'
				. ' WHERE h.id = '.$restaurant
				. ' AND r.parent_id = 0'
				. ' AND ri.minprice > 0'
				;	
				
		$this->_db->setQuery($query);
		$rooms = $this->_db->loadObjectList();
		
		$count = count($rooms);

		for($i = 0; $i < $count; $i++)
		{
			$room = $rooms[$i];

			$query = 'SELECT DISTINCT rr.*'
					. ' FROM #__rg_roomrates AS rr'
					. ' LEFT JOIN #__rg_roomitems AS i ON i.id = rr.room_id'
					. ' WHERE rr.room_id = '.(int)$room->id
					;

			$this->_db->setQuery( $query );
			$rooms[$i]->beds = $this->_db->loadObjectList();
			
			$query = 'SELECT DISTINCT r.*'
					. ' FROM #__rg_roomitems AS r'
					. ' LEFT JOIN #__rg_roomrates AS ri ON ri.room_id = r.id'
					. ' WHERE r.parent_id = ' . (int)$room->id
					. ' AND ri.minprice > 0'
					;	
					
			$this->_db->setQuery($query);		
			$rooms[$i]->subrate = $this->_db->loadObjectList();

			$nosubrate = count($rooms[$i]->subrate);
			
			if ($nosubrate > 0) {
				for($j = 0; $j < $nosubrate; $j++) {
					$query = 'SELECT DISTINCT rr.*'
							. ' FROM #__rg_roomrates AS rr'
							. ' LEFT JOIN #__rg_roomitems AS i ON i.id = rr.room_id'
							. ' WHERE rr.room_id = '.$rooms[$i]->subrate[$j]->id
							;
		
					$this->_db->setQuery( $query );
					$rooms[$i]->subrate[$j]->beds = $this->_db->loadObjectList();
				}
			}
		}
		
		return $rooms;
	}
}
?>