<?php
/**
 * @version 1.0 $Id: restaurantitem.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RESTAURANTGUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component RestaurantItem Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelRestaurantItem extends JModel
{
	/**
	 * Item data
	 *
	 * @var object
	 */
	var $_item = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$cid = JRequest::getVar( 'cid', array(0), '', 'array' );
		JArrayHelper::toInteger($cid, array(0));
		$this->setId($cid[0]);
	}

	/**
	 * Method to set the identifier
	 *
	 * @access	public
	 * @param	int item identifier
	 */
	function setId($id)
	{
		// Set item id and wipe data
		$this->_id	    = $id;
		$this->_item	= null;
	}
	
	/**
	 * Overridden get method to get properties from the item
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.0
	 */
	function get($property, $default=null)
	{
		if ($this->_loadItem()) {
			if(isset($this->_item->$property)) {
				return $this->_item->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to get item data
	 *
	 * @access	public
	 * @return	array
	 * @since	1.0
	 */
	function &getItem()
	{		
		if ($this->_loadItem())
		{		
			$query = 'SELECT name'
					. ' FROM #__users'
					. ' WHERE id = '. (int) $this->_item->created_by
					;
			$this->_db->setQuery($query);
			$this->_item->creator = $this->_db->loadResult();

			//reduce unneeded query
			if ($this->_item->created_by == $this->_item->modified_by) {
				$this->_item->modifier = $this->_item->creator;
			} else {
				$query = 'SELECT name'
						. ' FROM #__users'
						. ' WHERE id = '. (int) $this->_item->modified_by
						;
				$this->_db->setQuery($query);
				$this->_item->modifier = $this->_db->loadResult();
			}
			
		}
		else  $this->_initItem();

		return $this->_item;
	}


	/**
	 * Method to load item data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _loadItem()
	{
		// Lets load the item if it doesn't already exist
		if (empty($this->_item))
		{
			$query = 'SELECT *'
					. ' FROM #__rg_restaurantitems'
					. ' WHERE id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_item = $this->_db->loadObject();
			
			return (boolean) $this->_item;
		}
		return true;
	}

	/**
	 * Method to initialise the item data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _initItem()
	{
		// Lets load the item if it doesn't already exist
		if (empty($this->_item))
		{
			$createdate = & JFactory::getDate();
			$nullDate	= $this->_db->getNullDate();
			
			$item = new stdClass();
			$item->id					= 0;
			$item->user_id				= 0;
			$item->title				= null;
			$item->alias				= null;
			$item->mainimage			= null;
			$item->logoimage			= null;
			$item->imagewidth			= null;
			$item->imageheight			= null;
			$item->address				= null;
			$item->parent_id			= 0;
			$item->city					= 0;
			$item->states				= 0;
			$item->country				= 0;
			$item->zipcode				= null;
			$item->phone				= null;
			$item->fax					= null;
			$item->chain				= 0;
			$item->dresscode			= null;
			$item->businesshr			= null;
			$item->holiday				= null;
			$item->seats				= null;
			$item->payment				= null;
			$item->language				= null;
			$item->diningstyle			= null;
			$item->executivechef		= null;
			$item->parking				= null;
			$item->parkingdetails		= null;
			$item->additionaldetails	= null;
			$item->alternatives			= null;
			$item->currency				= 0;
			$item->pricerange			= 0;
			$item->branches				= null;
			$item->text					= null;
			$item->rate					= 0;
			$item->rate_sum				= 0;
			$item->hits					= 0;
			$item->post_hits			= 0;
			$item->version				= 0;
			$item->booking				= null;
			$item->website				= null;
			$item->email				= null;
			$item->meta_title			= null;
			$item->meta_description		= null;
			$item->meta_keywords		= null;
			$item->created				= $createdate->toUnix();
			$item->created_by			= null;
			$item->created_by_alias		= '';
			$item->modified				= $nullDate;
			$item->modified_by			= null;
			$item->attribs				= null;
			$item->metadata				= null;
			$item->urldata				= null;
			$item->ordering 			= null;
			$item->published			= 1;
			$item->tid					= 0;
			$item->gid					= 0;
			$item->featured				= 0;
			$item->facilities			= null;
			$item->cuisines				= null;
			$item->atmos				= null;
			$item->checklists			= null;
			$item->menus				= null;
			$item->menu_desc			= null;
			$item->service				= null;
			$item->activity				= null;
			$item->bookingtime			= null;
			$item->rangeoftrip			= null;
			$item->introduction			= null;
			$item->eat					= null;
			$item->drink				= null;
			$item->price				= null;
			$item->catering				= null;
			$item->privateparty			= null;
			$item->roominfo				= null;
			$item->seating				= null;
			$item->venue				= null;
			$item->promotions			= null;
			$item->lat					= null;
			$item->lon					= null;
			$item->slideshow			= null;
			$item->slideshowposition	= null;
			$item->slideshowfloat		= null;
			$item->slideshowwidth		= null;
			$item->slideshowheight		= null;
			$item->infoheight			= 27;
			$item->delay				= 8000;
			$item->contact				= null;
			$this->_item				= $item;
			return (boolean) $this->_item;
		}
		return true;
	}

	/**
	 * Method to checkin/unlock the item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$item = & JTable::getInstance('rg_restaurantitems', '');
			return $item->checkin($this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the item
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the group with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$item = & JTable::getInstance('rg_restaurantitems', '');
			return $item->checkout($uid, $this->_id);
		}
		return false;
	}

	/**
	 * Tests if the item is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadItem())
		{
			if ($uid) {
				return ($this->_item->checked_out && $this->_item->checked_out != $uid);
			} else {
				return $this->_item->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}

	/**
	 * Method to store the item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function store($data)
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
				
		$item  =& $this->getTable('rg_restaurantitems', '');
		$user	=& JFactory::getUser();

		$tags 		= JRequest::getVar( 'tag', array(), 'post', 'array');
		
		$old_rate = $item->rate;
		$old_rate_sum = $item->rate_sum;

		// bind it to the table
		if (!$item->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		
		$item->bind($details);

		// sanitise id field
		$item->id = (int) $item->id;
		
		$nullDate	= $this->_db->getNullDate();

		// Are we saving from an item edit?
		if ($item->id) {
			$item->modified 		= gmdate('Y-m-d H:i:s');
			$item->modified_by 		= $user->get('id');
		} else {
			$item->modified 		= $nullDate;
			$item->modified_by 		= '';

			//get time and userid
			$item->created 			= gmdate('Y-m-d H:i:s');
			$item->created_by		= $user->get('id');
		}
		
		// Get a state and parameter variables from the request
		$item->published	= JRequest::getVar( 'published', 0, '', 'int' );

		// Get metadata string
		$metadata = JRequest::getVar( 'meta', null, 'post', 'array');
		
		if ($metadata)
		{
			$txt = array();
			foreach ($metadata as $k => $v) {
				if ($k == 'title') {
					$item->meta_title = $v;
				} elseif ($k == 'description') {
					$item->meta_description = $v;
				} elseif ($k == 'keywords') {
					$item->meta_keywords = $v;
				} else {
					$txt[] = "$k=$v";
				}
			}
			$item->metadata = implode("\n", $txt);
		}
		
		if (!$item->id) {
			$item->ordering = $item->getNextOrder();
		}
		
		// Make sure the data is valid
		if (!$item->check()) {
			$this->setError($item->getError());
			return false;
		}

		$item->version++;
		
		// Store it in the db
		if (!$item->store()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		
		$this->_item	=& $item;
		
		//store tag relation
		$query = 'DELETE FROM #__rg_tags_item_relations WHERE itemid = '.$item->id;
		$this->_db->setQuery($query);
		$this->_db->query();
			
		foreach($tags as $tag)
		{
			$query = 'INSERT INTO #__rg_tags_item_relations (`tid`, `itemid`) VALUES(' . $tag . ',' . $item->id . ')';
			$this->_db->setQuery($query);
			$this->_db->query();
		}

		return true;
	}

	/**
	 * Method to reset hits
	 * 
	 * @param int id
	 * @return int
	 * @since 1.0
	 */
	function resetHits($id)
	{
		$row  =& $this->getTable('rg_restaurantitems', '');
		$row->load($id);
		$row->hits = 0;
		$row->store();
		$row->checkin();
		return $row->id;
	}
	
	/**
	 * Method to reset votes
	 * 
	 * @param int id
	 * @return int
	 * @since 1.0
	 */
	function resetVotes($id)
	{
		$row  =& $this->getTable('rg_restaurantitems', '');
		$row->load($id);
		$row->plus = 0;
		$row->minus = 0;
		$row->store();
		$row->checkin();
		return $row->id;
	}
	
	/**
	 * Method to fetch tags
	 * 
	 * @return object
	 * @since 1.0
	 */
	function gettags($type)
	{
		$query = 'SELECT * FROM #__rg_tags WHERE type = '.$type.' ORDER BY name';
		$this->_db->setQuery($query);
		$tags = $this->_db->loadObjectlist();
		return $tags;
	}
	
	/**
	 * Method to fetch used tags when performing an edit action
	 * 
	 * @param int id
	 * @return array
	 * @since 1.0
	 */
	function getusedtags($id)
	{
		$query = 'SELECT DISTINCT tid FROM #__rg_tags_item_relations WHERE itemid = ' . (int)$id;
		$this->_db->setQuery($query);
		$used = $this->_db->loadResultArray();
		return $used;
	}
	
	function getusedtagname($id)
	{
		$query = 'SELECT GROUP_CONCAT(DISTINCT t.name ORDER BY t.name ASC SEPARATOR \', \') AS tags'
				. ' FROM #__rg_tags_item_relations AS r'
				. ' LEFT JOIN #__rg_tags AS t ON t.id = r.tid'
				. ' WHERE r.itemid = ' . (int)$id
				;

		$this->_db->setQuery($query);
		$used = $this->_db->loadObject();
		return $used;
	}
	
	/**
	 * Method to reset hits
	 * 
	 * @param int id
	 * @return object
	 * @since 1.0
	 */
	function getvotes($id)
	{
		$query = 'SELECT plus, minus FROM #__rg_restaurantitems WHERE id = '.(int)$id;
		$this->_db->setQuery($query);
		$votes = $this->_db->loadObjectlist();
		
		return $votes;
	}
	
	/**
	 * Method to get hits
	 * 
	 * @param int id
	 * @return int
	 * @since 1.0
	 */
	function gethits($id)
	{
		$query = 'SELECT hits FROM #__rg_restaurantitems WHERE id = '.(int)$id;
		$this->_db->setQuery($query);
		$hits = $this->_db->loadResult();
		
		return $hits;
	}
	
	function getRate($id)
	{
		$query = 'SELECT rate FROM #__rg_restaurantitems WHERE id = '.(int)$id;
		$this->_db->setQuery($query);
		$rate = $this->_db->loadResult();
		
		return $rate;
	}
	
	function getRateSum($id)
	{
		$query = 'SELECT rate_sum FROM #__rg_restaurantitems WHERE id = '.(int)$id;
		$this->_db->setQuery($query);
		$ratesum = $this->_db->loadResult();
		
		return $ratesum;
	}

	function getMenus()
	{
		$query = 'SELECT DISTINCT m.*, i.title AS restoname'
				. ' FROM #__rg_menus AS m'
				. ' LEFT JOIN #__rg_restaurantitems AS i ON i.id = m.resto'
				. ' WHERE i.id = ' . (int)$this->_id
				;	
				
		$this->_db->setQuery($query);
		$rows = $this->_db->loadObjectList();
		
		//establish the hierarchy of the menus
		$children = array();
		
    	//set depth limit
   		$levellimit = 10;
		
    	foreach ($rows as $child) {
        	$parent = $child->parent_id;
       		$list 	= @$children[$parent] ? $children[$parent] : array();
        	array_push($list, $child);
        	$children[$parent] = $list;
    	}
		
		//get list of the items
    	$list = restaurantguide_menus::treerecurse(0, '', array(), $children, false, max(0, $levellimit-1));
		
		return $list;
	}
	
	function getGallery()
	{
		$query = 'SELECT DISTINCT i.*'
				. ' FROM #__rg_galleryitems AS i'
				. ' LEFT JOIN #__rg_restaurantitems AS r ON r.id = i.resto'
				. ' WHERE r.id = ' . (int)$this->_id
				;

		$this->_db->setQuery($query);
		$gallery = $this->_db->loadObjectList();
		return $gallery;
	}
	
	function getPromotions()
	{
		$query = 'SELECT DISTINCT i.*, r.title AS restoname'
				. ' FROM #__rg_promotions AS i'
				. ' LEFT JOIN #__rg_restaurantitems AS r ON r.id = i.resto'
				. ' WHERE r.id = ' . (int)$this->_id
				;	
				
		$this->_db->setQuery($query);
		$promotions = $this->_db->loadObjectList();
		return $promotions;
	}
	
	function getSpecialOffers()
	{
		$query = 'SELECT DISTINCT i.*, r.title AS restoname'
				. ' FROM #__rg_specialoffers AS i'
				. ' LEFT JOIN #__rg_restaurantitems AS r ON r.id = i.resto'
				. ' WHERE r.id = ' . (int)$this->_id
				;	
				
		$this->_db->setQuery($query);
		$specialoffers = $this->_db->loadObjectList();
		return $specialoffers;
	}
}
?>