<?php
/**
 * @version 1.0 $Id: states.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component states Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelStates extends JModel
{
	var $_app = null;					// constructor gets the app
	
	/**
	 * Type data
	 *
	 * @var object
	 */
	var $_data = null;

	/**
	 * Type total
	 *
	 * @var integer
	 */
	var $_total = null;

	/**
	 * Pagination object
	 *
	 * @var object
	 */
	var $_pagination = null;

	/**
	 * Type id
	 *
	 * @var int
	 */
	var $_id = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$this->_app = &JFactory::getApplication();

		$limit		= $this->_app->getUserStateFromRequest( RG_OPTION.'.limit', 'limit', $this->_app->getCfg('list_limit'), 'int');
		$limitstart = $this->_app->getUserStateFromRequest( RG_OPTION.'.states.limitstart', 'limitstart', 0, 'int' );

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	/**
	 * Method to set the Type identifier
	 *
	 * @access	public
	 * @param	int Type identifier
	 */
	function setId($id)
	{
		// Set id and wipe data
		$this->_id	 = $id;
		$this->_data = null;
	}

	/**
	 * Method to get types data
	 *
	 * @access public
	 * @return array
	 */
	function getData()
	{
		// Lets load the types if it doesn't already exist
		if (empty($this->_data))
		{
			$query = $this->_buildQuery();
			
			$this->_db->setQuery( $query );
			$rows = $this->_db->loadObjectList();

			$total = count( $rows );
			
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination( $total, $this->getState('limitstart'), $this->getState('limit') );

			$this->_data = array_slice( $rows, $this->_pagination->limitstart, $this->_pagination->limit );
		}
		return $this->_data;
	}

	/**
	 * Method to get the total nr of the types
	 *
	 * @access public
	 * @return integer
	 */
	function getTotal()
	{
		// Lets load the types if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);
		}

		return $this->_total;
	}

	/**
	 * Method to get a pagination object for the types
	 *
	 * @access public
	 * @return integer
	 */
	function getPagination()
	{
		// Lets load the types if it doesn't already exist
		if (empty($this->_pagination))
		{
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination( $this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}

		return $this->_pagination;
	}

	/**
	 * Method to build the query for the types
	 *
	 * @access private
	 * @return integer
	 * @since 1.0
	 */
	function _buildQuery()
	{
		// Get the WHERE, HAVING and ORDER BY clauses for the query
		$where		= $this->_buildContentWhere();
		$orderby	= $this->_buildContentOrderBy();

		$query = 'SELECT s.*, c.name AS countryname, u.name AS editor'
				. ' FROM #__rg_states AS s'
				. ' LEFT JOIN #__rg_countries AS c ON c.id = s.country'
				. ' LEFT JOIN #__users AS u ON u.id = s.checked_out'
				. $where
				. ' GROUP BY s.id'
	//			. $orderby
				;

		return $query;

	}

	/**
	 * Method to build the orderby clause of the query for the types
	 *
	 * @access private
	 * @return string
	 * @since 1.0
	 */
	function _buildContentOrderBy()
	{
		$filter_order		= $this->_app->getUserStateFromRequest( RG_OPTION.'.states.filter_order', 'filter_order', 's.name', 'cmd' );
		$filter_order_Dir	= $this->_app->getUserStateFromRequest( RG_OPTION.'.states.filter_order_Dir', 'filter_order_Dir', 'ASC', 'word' );

		$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_Dir;
		return $orderby;
	}

	/**
	 * Method to build the where clause of the query for the types
	 *
	 * @access private
	 * @return string
	 * @since 1.0
	 */
	function _buildContentWhere()
	{
		$filter_state 		= $this->_app->getUserStateFromRequest( RG_OPTION.'.states.filter_state', 'filter_state', '', 'word' );
		$search 			= $this->_app->getUserStateFromRequest( RG_OPTION.'.states.search', 'search', '', 'string' );
		$search 			= $this->_db->getEscaped( trim(JString::strtolower( $search ) ) );

		$where = array();

		if ( $filter_state ) {
			if ( $filter_state == 'P' ) {
				$where[] = 's.published = 1';
			} else if ($filter_state == 'U' ) {
				$where[] = 's.published = 0';
			}
		}

		if ($search) {
			$where[] = ' LOWER(s.name) LIKE '.$this->_db->Quote( '%'.$this->_db->getEscaped( $search, true ).'%', false );
		}

		$where 		= ( count( $where ) ? ' WHERE ' . implode( ' AND ', $where ) : '' );

		return $where;
	}

	/**
	 * Method to (un)publish a type
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function publish($cid = array(), $publish = 1)
	{
		$user 	=& JFactory::getUser();

		if (count( $cid ))
		{
			$cids = implode( ',', $cid );

			$query = 'UPDATE #__rg_states'
				. ' SET published = ' . (int) $publish
				. ' WHERE id IN ('. $cids .')'
				. ' AND ( checked_out = 0 OR ( checked_out = ' . (int) $user->get('id'). ' ) )'
			;
			$this->_db->setQuery( $query );
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}
		return true;
	}

	/**
	 * Method to remove a type
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function delete($cid = array())
	{
		$result = false;

		if (count( $cid ))
		{
			$cids = implode( ',', $cid );
			$query = 'DELETE FROM #__rg_states'
					. ' WHERE id IN ('. $cids .')'
					;
			$this->_db->setQuery( $query );
			if(!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}

		return true;
	}

	/**
	 * Method to set the access level of the Types
	 *
	 * @access	public
	 * @param 	integer id of the category
	 * @param 	integer access level
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function access($id, $access)
	{
		$row =& JTable::getInstance('rg_states', '');

		$row->load( $this->_id );
		$row->id = $id;
		$row->access = $access;

		if ( !$row->check() ) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		if ( !$row->store() ) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		
		$this->_app->redirect( 'index.php?option=com_restaurantguide&view=states' );
	}
}
?>