<?php
/**
 * @version 1.0 $Id: restaurantguide_files.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RESTAURANTGUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport( 'joomla.application.component.view');

/**
 * View class for the RestaurantGuide restaurant item screen
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since 1.0
 */
class restaurantguideViewRestaurantItem extends restaurantguideView {

	function __construct( $config = array() )
	{
		parent::__construct($config);

	}
	
	function displayDefault()
	{
		global $mainframe, $rgconf;

		JHTML::_('behavior.tooltip');

		//initialise variables
		$editor 	= & JFactory::getEditor();
		$document	= & JFactory::getDocument();
		$user 		= & JFactory::getUser();
		$db  		= & JFactory::getDBO();
		$lang 		= & JFactory::getLanguage();
		
		$nullDate	= $db->getNullDate();
		
		//get vars
		$cid 		= JRequest::getVar( 'cid' );

		$document->addScript( JURI::base().'components/com_restaurantguide/assets/js/itemscreen.js' );
		
		//create the toolbar
		if ( $cid ) {
			JToolBarHelper::title( JText::_( 'RG_EDIT_RESTAURANT' ), 'restaurants' );

		} else {
			JToolBarHelper::title( JText::_( 'RG_NEW_RESTAURANT' ), 'restaurants' );
		}
		JToolBarHelper::apply();
		JToolBarHelper::save();
		JToolBarHelper::custom( 'saveandnew', 'savenew.png', 'savenew.png', 'RG_SAVE_AND_NEW', false );
		JToolBarHelper::cancel();

		//Get data from the model
		$model		= & $this->getModel();
		$row 		= & $this->get('Item');
		$menus	 	= & $this->get('Menus');
		$images 	= & $this->get('Gallery');
		$promotions = & $this->get('Promotions');
		$specialoffers = & $this->get('SpecialOffers');
		$usedtags	= $model->getusedtagname($cid);

		// fail if checked out not by 'me'
		if ($row->id) {
			if ($model->isCheckedOut( $user->get('id') )) {
				JError::raiseWarning( 'SOME_ERROR_CODE', $row->title.' '.JText::_( 'RG_EDITED_BY_ANOTHER_ADMIN' ));
				$mainframe->redirect( 'index.php?option=com_restaurantguide&view=restaurantguide' );
			}
		}

		//clean data
		JFilterOutput::objectHTMLSafe( $row, ENT_QUOTES, 'text' );
	    	
		//build selectlists
		$lists = array();

		// Create the form
		$form = new JParameter('', RESTAURANTGUIDE_MODELS.DS.'restaurantitem.xml');

		// Details Group
		$active = (intval($row->created_by) ? intval($row->created_by) : $user->get('id'));
		$form->set('created_by', $active);
		$form->set('created_by_alias', $row->created_by_alias);
		$form->set('created', JHTML::_('date', $row->created, '%Y-%m-%d %H:%M:%S'));

		// Metadata Group
		if (!$row->meta_title)
			$form->set('title', $row->title);
		else if ($row->meta_title)
			$form->set('title', $row->meta_title);
		else
			$form->set('title', $row->title);
			
		if ($row->meta_description)
			$form->set('description', $row->meta_description);
//		else if (!$row->meta_description && $row->introduction)
//			$form->set('description', strip_tags($row->introduction));
			
		if (!$row->meta_keywords)
			$form->set('keywords', $row->title);
		else if ($row->meta_keywords)
			$form->set('keywords', $row->meta_keywords);
		else if ($usedtags && !$row->meta_keywords)
			$form->set('keywords', $row->title . ', ' . $usedtags->tags);
			
		$form->loadINI($row->metadata); 

		//build state list
		$state[] = JHTML::_('select.option',  1, JText::_( 'RG_PUBLISHED' ) );
		$state[] = JHTML::_('select.option',  0, JText::_( 'RG_UNPUBLISHED' ) );

		$lists['published'] = JHTML::_('select.genericlist', $state, 'published', '', 'value', 'text', $row->published );

		$db->setQuery( "SELECT * FROM #__rg_currency WHERE published = 1 AND id =".$rgconf->currency);
		$defaultcurrency = $db->loadObject();
		
		$db->setQuery( "SELECT * FROM #__rg_facilities WHERE published = 1 ORDER BY name ASC");
		$facilities = $db->loadObjectList();

		if ($db->getErrorNum()) 
		{
			return $db->getErrorMsg();
		}

		$aSelected = explode(",", $row->facilities );

		$i = 1;
		$facilityList = "";
		foreach ( $facilities as $facility )
		{
			$bChecked = false;
			if ( in_array( $facility->id, $aSelected ) )
			{
				$bChecked = true;
			}

			if ( $i == 1 )
			{
				$facilityList .= "<tr>";
			}
			$facilityList .= '<td width="150"><input type="checkbox" name="isFacility" value="'.$facility->id.'" onClick="updateCheckedList();" ';
			$facilityList .= ( $bChecked ? " checked" : "" ) ;
			$facilityList .= "/>";
			$facilityList .= $facility->name;
			$facilityList .="</td>";

			if ( $i == 4 ) 
			{
				$i=1;
				$facilityList .= "</tr>";
			}else {
				$i++;
			}
		}

		$db->setQuery( "SELECT * FROM #__rg_cuisines WHERE published = 1 AND atmosphere = 0 ORDER BY name ASC");
		$cuisines = $db->loadObjectList();

		if ($db->getErrorNum()) 
		{
			return $db->getErrorMsg();
		}

		$bSelected = explode(",", $row->cuisines );

		$i = 1;
		$cuisineList = '<div class="rg_tagbox">';
		foreach ( $cuisines as $cuisine )
		{
			$bCuisine = false;
			if ( in_array( $cuisine->id, $bSelected ) )
			{
				$bCuisine = true;
			}

			$cuisineList .=  '<div class="rg_tagline">';
			
			$cuisineList .=  '<span class="rg_tag"><span class="rg_tagidbox"><input type="checkbox" name="isCuisine" value="'.$cuisine->id.'" onClick="updateCuisineList();" '.( $bCuisine ? " checked" : "" ).' /></span>'.$cuisine->name.'</span>';

			if ( $i == 3 ) 
			{
				$i=1;
				$cuisineList .= "</div>";
			}else {
				$i++;
			}
		}
		$cuisineList .= "</div>";

		$db->setQuery( "SELECT * FROM #__rg_cuisines WHERE published = 1 AND atmosphere = 1 ORDER BY name ASC");
		$atmos = $db->loadObjectList();

		if ($db->getErrorNum()) 
		{
			return $db->getErrorMsg();
		}

		$cSelected = explode(",", $row->atmos );

		$i = 1;
		$atmoList = '<div class="rg_tagbox">';
		foreach ( $atmos as $atmo )
		{
			$bAtmo = false;
			if ( in_array( $atmo->id, $cSelected ) )
			{
				$bAtmo = true;
			}

			$atmoList .=  '<div class="rg_tagline">';
			
			$atmoList .=  '<span class="rg_tag"><span class="rg_tagidbox"><input type="checkbox" name="isAtmo" value="'.$atmo->id.'" onClick="updateAtmoList();" '.( $bAtmo ? " checked" : "" ).' /></span>'.$atmo->name.'</span>';

			if ( $i == 3 ) 
			{
				$i=1;
				$atmoList .= "</div>";
			}else {
				$i++;
			}
		}
		$atmoList .= "</div>";
		
		
		$db->setQuery( "SELECT * FROM #__rg_checklists WHERE published = 1 ORDER BY name ASC");
		$checklists = $db->loadObjectList();

		if ($db->getErrorNum()) 
		{
			return $db->getErrorMsg();
		}

		$dSelected = explode(",", $row->checklists );

		$i = 1;
		$checkLists = '<div class="rg_tagbox">';
		foreach ( $checklists as $checklist )
		{
			$bCheck = false;
			if ( in_array( $checklist->id, $dSelected ) )
			{
				$bCheck = true;
			}

			$checkLists .=  '<div class="rg_tagline">';
			
			$checkLists .=  '<span class="rg_tag"><span class="rg_tagidbox"><input type="checkbox" name="isChecklist" value="'.$checklist->id.'" onClick="updateCheckList();" '.( $bCheck ? " checked" : "" ).' /></span>'.$checklist->name.'</span>';

			if ( $i == 3 ) 
			{
				$i=1;
				$checkLists .= "</div>";
			}else {
				$i++;
			}
		}
		$checkLists .= "</div>";
		
		//assign vars to view
		$this->assignRef('rgconf', 		$rgconf);
		$this->assignRef('user', 		$user);
		$this->assignRef('nullDate', 	$nullDate);
		$this->assignRef('form', 		$form);
		$this->assignRef('lists', 		$lists);
		$this->assignRef('row', 		$row);
		$this->assignRef('editor', 		$editor);
		$this->assignRef('facilityList', $facilityList);
		$this->assignRef('cuisineList', $cuisineList);
		$this->assignRef('atmoList', 	$atmoList);
		$this->assignRef('checkLists', 	$checkLists);
		$this->assignRef('images', 		$images);
		$this->assignRef('menus', 		$menus);
		$this->assignRef('promotions', 	$promotions);
		$this->assignRef('specialoffers', 	$specialoffers);
		$this->assignRef('defaultcurrency', 	$defaultcurrency);
/*		
		echo "<pre>";
		echo "view=";
		print_r($usedtags);
		echo "</pre>"; 
*/
	}
	
	function setImage($index = 0)
	{
		if (isset($this->images[$index])) {
			$this->_tmp_img = &$this->images[$index];
			$this->_tmp_img->path = "../images/restaurantguide/gallery/restaurant_".$this->_tmp_img->resto."/thumb/".$this->_tmp_img->filename;
		} else {
			$this->_tmp_img = new JObject;
		}
	}
}
?>