<?php
/**
 * @version 1.0 $Id: restaurantguide_files.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with HOTELGUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelCountry extends JModel
{
	var $_id = null;
	var $_data = null;
	var $_total = null;
	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$app = JFactory::getApplication('site');

		// Get the paramaters of the active menu item
		$params = $app->getParams();
		
		$id = JRequest::getInt('cid', 0);
		
		if (!$id)
			$id = JRequest::getInt('id', 0);

		$this->setId((int)$id);

		//set limits
		$limit			= $app->getUserStateFromRequest('com_restaurantguide.country.limit', 'limit', $app->def('limit', 0), 'int');
		$limitstart		= JRequest::getInt('limitstart');

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);

		$this->setState('filter_order', JRequest::getCmd('filter_order', 'i.title'));
		$this->setState('filter_order_dir', JRequest::getCmd('filter_order_Dir', 'ASC'));
	}
	
	function setId($cid)
	{
		// Set new destination ID and wipe data
		$this->_id = $cid;
	}

	function getData()
	{
		// Lets load the categories if it doesn't already exist
		if (empty($this->_data))
		{
			//get data
			$this->_data = $this->_getList( $this->_buildQuery(), $this->getState('limitstart'), $this->getState('limit') );
			
			$count = count($this->_data);

			$i = 0;
			foreach($this->_data as $data) :
				$temp = $data->cuisines;
				$where = ' WHERE published = 1';
				if ($temp) {
					$where .= ' AND id IN ('.$temp.')';
				} else {
					$where .= ' AND id = 0';
				}

				$query = 'SELECT GROUP_CONCAT(DISTINCT name ORDER BY name ASC SEPARATOR \', \') AS cuisines'
					. ' FROM #__rg_cuisines'
					. $where
					;
					
				$this->_db->setQuery($query);
				$this->_data[$i]->cuisinelist = $this->_db->loadObject();
				
				$temp = $data->tags;
				$where = ' WHERE published = 1';
				if ($temp) {
					$where .= ' AND id IN ('.$temp.')';
				} else {
					$where .= ' AND id = 0';
				}
				$query = 'SELECT DISTINCT name,'
						. ' CASE WHEN CHAR_LENGTH(alias) THEN CONCAT_WS(\':\', id, alias) ELSE id END as slug'
						. ' FROM #__rg_tags'
						. $where
						. ' ORDER BY name ASC'
						;
				
				$this->_db->setQuery($query);
				$this->_data[$i]->taglist = $this->_db->loadObjectList();
				
				$i ++;
			endforeach;
		}

		return $this->_data;
	}
	
	function _buildItemWhere( )
	{
		$app = JFactory::getApplication('site');

		// Get the paramaters of the active menu item
		$params = $app->getParams();

		$where = ' WHERE i.published = 1';
		$where .= ' AND i.country = '.$this->_id;

		/*
		* If we have a filter, and this is enabled... lets tack the AND clause
		* for the filter onto the WHERE clause of the item query.
		*/
		if ($params->get('filter'))
		{
			$filter = JRequest::getString('filter', '', 'request');

			if ($filter)
			{
				// clean filter variables
				$filter = $this->_db->getEscaped( trim(JString::strtolower( $filter ) ) );

				$where .= ' AND LOWER( i.title ) LIKE '.$this->_db->Quote( '%'.$this->_db->getEscaped( $filter, true ).'%', false );
			}
		}
		return $where;
	}
	
	function _buildItemOrderBy()
	{
		$filter_order		= $this->getState('filter_order');
		$filter_order_dir	= $this->getState('filter_order_dir');

		if ($filter_order == 'title')
			$orderby 	= ' ORDER BY i.title '.$filter_order_dir;
		else if ($filter_order == 'hits')
			$orderby 	= ' ORDER BY i.hits '.$filter_order_dir.', i.title ASC';
		else if ($filter_order == 'votes')
			$orderby 	= ' ORDER BY votes '.$filter_order_dir.', i.title ASC';
		else if ($filter_order == 'type')
			$orderby 	= ' ORDER BY restauranttype '.$filter_order_dir.', i.title ASC';
		else
			$orderby 	= ' ORDER BY i.title ASC';

		return $orderby;
	}
	
	/**
	 * Method to build the Categories query
	 *
	 * @access private
	 * @return string
	 */
	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildItemWhere();
		$orderby	= $this->_buildItemOrderBy();
	
		$query = 'SELECT DISTINCT i.*, (i.rate_sum / i.rate ) AS votes, t.name AS restauranttype, c.name AS countryname,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug,'	
					. ' (SELECT GROUP_CONCAT('
					. ' tag.tid ORDER BY tag.tid ASC SEPARATOR \', \')'
					. ' FROM #__rg_tags_item_relations AS tag'
					. ' WHERE tag.itemid IN(i.id)'
					. ' )' 
					. ' AS tags'
				. ' FROM #__rg_restaurantitems AS i'
				. ' LEFT JOIN #__rg_restauranttypes AS t ON t.id = i.tid'
				. ' LEFT JOIN #__rg_countries AS c on c.id = i.country'
				. $where
				. $orderby
				; 

		return $query;
	}

	/**
	 * Method to build the Categories query without subselect
	 * That's enough to get the total value.
	 *
	 * @access private
	 * @return string
	 */
	function _buildQueryTotal()
	{
		$query = 'SELECT i.id'
				. ' FROM #__rg_restaurantitems AS i'
				. ' LEFT JOIN #__rg_countries AS c on c.id = i.country'
				. ' WHERE i.published = 1'
				. ' AND i.country = '.$this->_id
				;

		return $query;
	}
	
	/**
	 * Total nr of Categories
	 *
	 * @access public
	 * @return integer
	 */
	function getTotal()
	{
		// Lets load the total nr if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQueryTotal();
			$this->_total = $this->_getListCount($query);
		}

		return $this->_total;
	}
	
	function getCityName()
	{			
		$query = 'SELECT s.*,'
				. ' CASE WHEN CHAR_LENGTH( s.alias ) THEN CONCAT_WS( \':\', s.id, s.alias ) ELSE s.id END AS statesslug'
				. ' FROM #__rg_states AS s'
				. ' WHERE s.published = 1'
				. ' AND s.country = '.$this->_id
				. ' ORDER BY s.name ASC'
				;
				
		$this->_db->setQuery( $query );
		$results = $this->_db->loadObjectList();
		$no = count($results);
		
		if ($no > 0) {
			for($i = 0; $i < $no; $i++) {
				$result = $results[$i];
				$query = 'SELECT c.*,'
						. ' CASE WHEN CHAR_LENGTH( c.alias ) THEN CONCAT_WS( \':\', c.id, c.alias ) ELSE c.id END AS cityslug,'
							. ' ('
							. ' SELECT COUNT( DISTINCT i.id )'
							. ' FROM #__rg_restaurantitems AS i'
							. ' LEFT JOIN #__rg_cities AS cc ON cc.id = i.city'
							. ' WHERE i.city = c.id'
							. ')' 
							. ' AS assignedrestos'
						. ' FROM #__rg_cities AS c'
						. ' WHERE c.published = 1'
						. ' AND c.states = '.$result->id
						. ' ORDER BY c.name ASC'
						;
						
				$this->_db->setQuery( $query );
				$results[$i]->city = $this->_db->loadObjectList();
			}
		} else {
			$query = 'SELECT c.*,'
					. ' CASE WHEN CHAR_LENGTH( c.alias ) THEN CONCAT_WS( \':\', c.id, c.alias ) ELSE c.id END AS cityslug,'
						. ' ('
						. ' SELECT COUNT( DISTINCT i.id )'
						. ' FROM #__rg_restaurantitems AS i'
						. ' LEFT JOIN #__rg_cities AS cc ON cc.id = i.city'
						. ' WHERE i.city = c.id'
						. ')' 
						. ' AS assignedrestos'
					. ' FROM #__rg_cities AS c'
					. ' WHERE c.published = 1'
					. ' AND c.parent_id = 0'
					. ' AND c.country = '.$this->_id
					. ' ORDER BY c.name ASC'
					;
					
			$this->_db->setQuery( $query );
			$results = $this->_db->loadObjectList();
		}

		return $results;
	}
	
	function getCountry()
	{			
		$query = 'SELECT t.*, COUNT(s.id) AS no'
				. ' FROM #__rg_countries AS t'
				. ' LEFT JOIN #__rg_states AS s ON s.country = t.id'
				. ' WHERE t.published = 1'
				. ' AND t.id = '.$this->_id
				;
				
		$this->_db->setQuery( $query );
		$result = $this->_db->loadObject();

		return $result;
	}
	
	function getSponsorAd()
	{			
		$query = 'SELECT i.*'
				. ' FROM #__rg_restaurantitems AS i'
				. ' LEFT JOIN #__rg_countries AS c on c.id = i.country'
				. ' LEFT JOIN #__rg_cities AS w on w.id = i.city'
				. ' LEFT JOIN #__rg_admanagers AS a on a.resto = i.id'
				. ' WHERE i.state = 1'
				. ' AND a.adid = 4'
				;
				
		$this->_db->setQuery( $query );
		$result = $this->_db->loadObjectList();

		return $result;
	}
	
	function getGallery()
	{
		$query = 'SELECT DISTINCT i.*'
				. ' FROM #__rg_galleryitems AS i'
				. ' WHERE i.country = ' . (int)$this->_id
				. ' AND i.resto < 1'
				. ' AND i.slideshow = 4'
				;

		$this->_db->setQuery($query);
		$gallery = $this->_db->loadObjectList();
		return $gallery;
	}
}
?>