<?php
/**
 * @version 1.0 $Id: restaurantguide_files.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RESTAURANTGUIDE; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component Item Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelRestaurant extends JModel
{
	/**
	 * Details data in details array
	 *
	 * @var array
	 */
	var $_item = null;
	
	var $_comments = null;

	/**
	 * id
	 *
	 * @var array
	 */
	var $_id = null;
	
	var $_articles = null;
	
	var $_cats = null;
	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$id = JRequest::getVar('id', 0, '', 'int');
		$this->setId((int)$id);
	}

	/**
	 * Method to set the restaurantitem id
	 *
	 * @access	public
	 * @param	int	restaurant ID number
	 */

	function setId($id)
	{
		// Set new restaurant ID
		$this->_id			= $id;
		$this->_item		= null;
	}

	/**
	 * Overridden get method to get properties from the item
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.5
	 */
	function get($property, $default=null)
	{
		if ($this->_loadItem()) {
			if(isset($this->_item->$property)) {
				return $this->_item->$property;
			}
		}
		return $default;
	}
	
	/**
	 * Overridden set method to pass properties on to the item
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function set( $property, $value=null )
	{
		if ($this->_loadItem()) {
			$this->_item->$property = $value;
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Method to get data for the itemview
	 *
	 * @access public
	 * @return array
	 * @since 1.0
	 */
	function &getItem( )
	{
		/*
		* Load the Item data
		*/
		if ($this->_loadItem())
		{
			$user	= & JFactory::getUser();

			//reduce unneeded query
			if ($this->_item->created_by_alias) {
				$this->_item->creator = $this->_item->created_by_alias;
			} else {
				$query = 'SELECT name'
				. ' FROM #__users'
				. ' WHERE id = '. (int) $this->_item->created_by
				;
				$this->_db->setQuery($query);
				$this->_item->creator = $this->_db->loadResult();
			}

			//reduce unneeded query
			if ($this->_item->created_by == $this->_item->modified_by) {
				$this->_item->modifier = $this->_item->creator;
			} else {
				$query = 'SELECT name'
				. ' FROM #__users'
				. ' WHERE id = '. (int) $this->_item->modified_by
				;
				$this->_db->setQuery($query);
				$this->_item->modifier = $this->_db->loadResult();
			}

			if ($this->_item->modified == $this->_db->getNulldate()) {
				$this->_item->modified = null;
			}

			//check session if uservisit already recorded
			$session 	=& JFactory::getSession();
			$hitcheck = false;
			if ($session->has('hit', 'restaurantguide')) {
				$hitcheck 	= $session->get('hit', 0, 'restaurantguide');
				$hitcheck 	= in_array($this->_item->id, $hitcheck);
			}
			if (!$hitcheck) {
				//record hit
				$this->hit();

				$stamp = array();
				$stamp[] = $this->_item->id;
				$session->set('hit', $stamp, 'restaurantguide');
			}
			//we show the introtext and fulltext (chr(13) = carriage return)
//			$this->_item->text = $this->_item->introtext . chr(13).chr(13) . $this->_item->fulltext;
		}
		else
		{
			$user =& JFactory::getUser();
			$item =& JTable::getInstance('rg_restaurantitems', '');
			if ($user->authorize('com_restaurantguide', 'state'))	{
				$item->state = 1;
			}
			$item->id					= 0;
			$item->author				= null;
			$item->created_by			= $user->get('id');
			$item->text					= '';
			$item->title				= null;
			$item->meta_description		= '';
			$item->meta_keywords		= '';
			$this->_item				= $item;
		}

		return $this->_item;
	}

	/**
	 * Method to load required data
	 *
	 * @access	private
	 * @return	array
	 * @since	1.0
	 */
	function _loadItem()
	{
		if($this->_id == '0') {
			return false;
		}

		if (empty($this->_item))
		{
			$query = 'SELECT i.*, (i.rate / (i.rate + i.rate_sum) ) AS votes, s.code_2 AS statescode,'
					. ' u.name AS author, u.usertype, ct.name AS cityname, cu.name AS countryname, t.name AS restauranttype,'
					. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug,'
					. ' CASE WHEN CHAR_LENGTH(ct.alias) THEN CONCAT_WS(\':\', cu.id, cu.alias) ELSE cu.id END as countryslug,'
					. ' CASE WHEN CHAR_LENGTH(ct.alias) THEN CONCAT_WS(\':\', ct.id, ct.alias) ELSE ct.id END as cityslug'
					. ' FROM #__rg_restaurantitems AS i'
					. ' LEFT JOIN #__rg_countries AS cu ON cu.id = i.country'
					. ' LEFT JOIN #__rg_states AS s ON s.id = i.states'
					. ' LEFT JOIN #__rg_cities AS ct ON ct.id = i.city'
					. ' LEFT JOIN #__rg_restauranttypes AS t ON t.id = i.tid'
					. ' LEFT JOIN #__users AS u ON u.id = i.created_by'
					. ' WHERE i.id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_item = $this->_db->loadObject();
			
			$where = ' WHERE published = 1';
			if ($this->_item->cuisines) {
				$where .= ' AND id IN ('.$this->_item->cuisines.')';
			} else {
				$where .= ' AND id = 0';
			}
				
			$query = 'SELECT GROUP_CONCAT(DISTINCT name ORDER BY name ASC SEPARATOR \', \') AS cuisines'
					. ' FROM #__rg_cuisines'
					. $where
					;
					
			$this->_db->setQuery($query);
			$this->_item->cuisinelist = $this->_db->loadObject();
			
			$where = ' WHERE published = 1';
			if ($this->_item->atmos) {
				$where .= ' AND id IN ('.$this->_item->atmos.')';
			} else {
				$where .= ' AND id = 0';
			}
				
			$query = 'SELECT GROUP_CONCAT(DISTINCT name ORDER BY name ASC SEPARATOR \', \') AS atmos'
					. ' FROM #__rg_cuisines'
					. $where
					;
					
			$this->_db->setQuery($query);
			$this->_item->atmolist = $this->_db->loadObject();
			
			$where = ' WHERE published = 1';
			if ($this->_item->facilities) {
				$where .= ' AND id IN ('.$this->_item->facilities.')';
			} else {
				$where .= ' AND id = 0';
			}

			$query = 'SELECT * FROM #__rg_facilities'
					. $where
					;
			
			$this->_db->setQuery($query);
			$this->_item->facilitylist = $this->_db->loadObjectList();
				
			$where = ' WHERE published = 1';
			if ($this->_item->checklists) {
				$where .= ' AND id IN ('.$this->_item->checklists.')';
			} else {
				$where .= ' AND id = 0';
			}

			$query = 'SELECT * FROM #__rg_checklists'
					. $where
					;
			
			$this->_db->setQuery($query);
			$this->_item->checklist = $this->_db->loadObjectList();
			
			$query = 'SELECT e.*'
					. ' FROM #__rg_events AS e'
					. ' LEFT JOIN #__rg_restaurantitems AS i ON i.id = e.resto'
					. ' WHERE e.published = 1'
					. ' AND e.resto = '.$this->_item->id
					. ' ORDER BY e.startdates DESC'
					;
				
			$this->_db->setQuery($query);	
			$this->_item->events = $this->_db->loadObjectList();
			
			$query = 'SELECT o.*'
					. ' FROM #__rg_specialoffers AS o'
					. ' LEFT JOIN #__rg_restaurantitems AS i ON i.id = o.resto'
					. ' WHERE o.published = 1'
					. ' AND o.resto = '.$this->_item->id
					. ' ORDER BY o.startdates DESC'
					;
				
			$this->_db->setQuery($query);	
			$this->_item->offers = $this->_db->loadObjectList();
				
			if ($this->_item->alternatives) {
				$query = 'SELECT i.id, i.title, i.tid, i.mainimage, i.address, i.introduction, i.pricerange, i.rate, i.rate_sum,'
						. ' d.name AS currencyname, d.symbol AS symbol, t.name AS restauranttype,'
						. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
						. ' FROM #__rg_restaurantitems AS i'
						. ' LEFT JOIN #__rg_currency AS d on d.id = i.currency'
						. ' LEFT JOIN #__rg_restauranttypes AS t ON t.id = i.tid'
						. ' WHERE i.id IN ('.$this->_item->alternatives.')'
						. ' ORDER BY i.title ASC'
						;
					
				$this->_db->setQuery($query);	
				$this->_item->alternativelist = $this->_db->loadObjectList();
			}
			
			return (boolean) $this->_item;
		}
		return true;
	}

	/**
	 * Method to increment the hit counter for the item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function hit()
	{
		if ($this->_id)
		{
			$item = & JTable::getInstance('rg_restaurantitems', '');
			$item->hit($this->_id);
			return true;
		}
		return false;
	}


	/**
	 * Tests if item is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadItem())
		{
			if ($uid) {
				return ($this->_item->checked_out && $this->_item->checked_out != $uid);
			} else {
				return $this->_item->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'Unable to Load Data');
			return false;
		}
	}

	/**
	 * Method to checkin/unlock the item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$item = & JTable::getInstance('rg_restaurantitems', '');
			return $item->checkin($this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the item
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the item with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$item = & JTable::getInstance('rg_restaurantitems', '');
			return $item->checkout($uid, $this->_id);
		}
		return false;
	}
	
	/**
	 * Method to store the item
	 *
	 * @access	public
	 * @since	1.0
	 */
	function store($data)
	{
		$item  		=& JTable::getInstance('rg_restaurantitems', '');
		$user     	=& JFactory::getUser();
		
		// Bind the form fields to the table
		if (!$item->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// sanitise id field
		$item->id = (int) $item->id;

		$isNew = ($item->id < 1);

		if ($isNew)
		{
			$item->created 		= gmdate('Y-m-d H:i:s');
			$item->created_by 	= $user->get('id');
		}
		else
		{
			$item->modified 	= gmdate('Y-m-d H:i:s');
			$item->modified_by 	= $user->get('id');

			$query = 'SELECT hits, rate, rate_sum, created, created_by, version' .
					' FROM #__rg_restaurantitems' .
					' WHERE id = '.(int) $item->id;

			$this->_db->setQuery($query);
			$result = $this->_db->loadObjectList();

			$item->rate = $result->rate;
			$item->rate_sum = $result->rate_sum;
			$item->hits = $result->hits;
			
			$item->created = $result->created;
			$item->created_by = $result->created_by;
			
			$item->version = $result->version;
			$item->version++;

			if (!$user->authorize('com_restaurantguide', 'state'))	{
				$item->state = $result->state;
			}
		}

		// Publishing state hardening for Authors
		if (!$user->authorize('com_restaurantguide', 'state'))
		{
			if ($isNew)
			{
				// For new restaurantitems
				$item->state = -2;
			}
			else
			{
				$query = 'SELECT state' .
						' FROM #__rg_restaurantitems' .
						' WHERE id = '.(int) $item->id;

				$this->_db->setQuery($query);
				$result = $this->_db->loadResult();

				$item->state = $result;
			}
		}
		
//		rg_html::saveContentPrep($item);

		// Make sure the data is valid
		if (!$item->check()) {
			$this->setError($item->getError());
			return false;
		}

		// Store the article table to the database
		if (!$item->store()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		if ($isNew)
		{
			$this->_id = $item->_db->insertId();
		}

		$item->ordering = $item->getNextOrder();

		$this->_item	=& $item;

		return $this->_item->id;
	}

	function gettags($type)
	{
		$query = 'SELECT * FROM #__rg_tags WHERE type = '.$type.' ORDER BY name';
		$this->_db->setQuery($query);
		$tags = $this->_db->loadObjectlist();
		return $tags;
	}
	
	function getusedtaglist($id)
	{
		$query = 'SELECT DISTINCT tid FROM #__rg_tags_item_relations WHERE itemid = ' . (int)$id;
		$this->_db->setQuery($query);
		$used = $this->_db->loadResultArray();
		return $used;
	}
	
	function getusedtagname($id)
	{
		$query = 'SELECT GROUP_CONCAT(DISTINCT t.name ORDER BY t.name ASC SEPARATOR \', \') AS tags'
				. ' FROM #__rg_tags_item_relations AS r'
				. ' LEFT JOIN #__rg_tags AS t ON t.id = r.tid'
				. ' WHERE r.itemid = ' . (int)$id
				;

		$this->_db->setQuery($query);
		$used = $this->_db->loadObject();
		return $used;
	}
	
	function getFavourites()
	{
		$query = 'SELECT COUNT(id) AS favs FROM #__rg_favourites WHERE itemid = '.(int)$this->_id;
		$this->_db->setQuery($query);
		$favs = $this->_db->loadResult();
		return $favs;
	}
	
	function getFavoured()
	{
		$user = JFactory::getUser();

		$query = 'SELECT COUNT(id) AS fav FROM #__rg_favourites WHERE itemid = '.(int)$this->_id.' AND userid= '.(int)$user->id;
		$this->_db->setQuery($query);
		$fav = $this->_db->loadResult();
		return $fav;
	}
	
	function removefav($itemid)
	{
		$user = JFactory::getUser();

		$query = 'DELETE FROM #__rg_favourites WHERE itemid = '.$itemid.' AND userid = '.(int)$user->id;
		$this->_db->setQuery($query);
		$remfav = $this->_db->query();
		return $remfav;
	}
	
	function addfav($itemid)
	{
		$user = JFactory::getUser();

		$obj = new stdClass();
		$obj->itemid 	= $itemid;
		$obj->userid	= $user->id;

		$addfav = $this->_db->insertObject('#__rg_favourites', $obj);
		return $addfav;
	}
	
	/**
	 * Method to store a vote
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function storevote($id, $vote)
	{
		if ($vote == 1) {
			$target = 'rate';
		} elseif ($vote == 0) {
			$target = 'rate_sum';
		} else {
			return false;
		}

		$query = 'UPDATE #__rg_restaurantitems'
				.' SET '.$target.' = ( '.$target.' + 1 )'
				.' WHERE id = '.(int)$id
				;
		$this->_db->setQuery($query);
		$this->_db->query();

		return true;
	}

	function storecomment($data)
	{
		$row  =& $this->getTable('rg_testimonial', '');

		// bind it to the table
		if (!$row->bind($data)) {
			JError::raiseError(500, $this->_db->getErrorMsg() );
			return false;
		}

		// Make sure the data is valid
		if (!$row->check()) {
			$this->setError($row->getError());
			return false;
		}

		// Store it in the db
		if (!$row->store()) {
			JError::raiseError(500, $this->_db->getErrorMsg() );
			return false;
		}

		return $row->id;
	}
	
	function addcomment($name)
	{
		$obj = new stdClass();
		$obj->name	 	= $name;
		$obj->published	= 1;

		$this->storecomment($obj);

		return true;
	}

	/**
	 * Method to change the state of an item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function setitemstate($id, $state = 1)
	{
		$user 	=& JFactory::getUser();
		
		if ( $id )
		{
			$query = 'UPDATE #__rg_restaurantitems'
					. ' SET state = ' . (int)$state
					. ' WHERE id = '.(int)$id
					. ' AND ( checked_out = 0 OR ( checked_out = ' . (int) $user->get('id'). ' ) )'
					;
			$this->_db->setQuery( $query );
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}
		return true;
	}
	
	function getRestaurantItem( $id )
	{
		// Where conditions
		$wheres[] = 'restaurant.id = ' . (int) $id;
					
		$query	= 	'SELECT restaurant.*, user.name AS postedby
					FROM #__rg_restaurantitems AS restaurant LEFT JOIN #__users AS user ON restaurant.user_id = user.id
					WHERE restaurant.published = "1" AND '. implode( ' AND ', $wheres );
 		$restaurantlist = $this->_getList( $query );
		return @$restaurantlist[0];
	}
	
	function getMapData()
	{
		$where = ' WHERE i.published = 1';
		$where .= ' AND i.lat > 0';
		$where .= ' AND i.lon > 0';
		if ($this->_item->city) {
			$where .= ' AND c.published = 1';
			$where .= ' AND c.id = '.$this->_item->city;
		} else {
			$where .= ' AND cu.published = 1';
			$where .= ' AND cu.id = '.$this->_item->country;
		}
					
		$query = 'SELECT DISTINCT i.id, i.title, i.lat, i.lon, i.mainimage, i.imagewidth, i.imageheight,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug,'
				. ' CASE WHEN CHAR_LENGTH(cu.alias) THEN CONCAT_WS(\':\', cu.id, cu.alias) ELSE cu.id END as countryslug,'
				. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as cityslug'
				. ' FROM #__rg_restaurantitems AS i'
				. ' LEFT JOIN #__rg_countries AS cu ON cu.id = i.country'
				. ' LEFT JOIN #__rg_cities AS c ON c.id = i.city'
				. $where
				. ' ORDER BY i.title ASC'
				;
		
		$this->_db->setQuery($query);
		$result = $this->_db->loadObjectList();

		return $result;
	}
	
	function getMenus()
	{
		$query = 'SELECT DISTINCT m.*, i.title AS restoname'
				. ' FROM #__rg_menus AS m'
				. ' LEFT JOIN #__rg_restaurantitems AS i ON i.id = m.resto'
				. ' WHERE i.id = ' . (int)$this->_id
				;	
				
		$this->_db->setQuery($query);
		$rows = $this->_db->loadObjectList();
		
		//establish the hierarchy of the menus
		$children = array();
		
    	//set depth limit
   		$levellimit = 10;
		
    	foreach ($rows as $child) {
        	$parent = $child->parent_id;
       		$list 	= @$children[$parent] ? $children[$parent] : array();
        	array_push($list, $child);
        	$children[$parent] = $list;
    	}
		
		//get list of the items
    	$list = restaurantguide_menus::recurse(0, '', array(), $children, false, max(0, $levellimit-1));
		
		return $list;
	}
	
	function getGallery()
	{
		$query = 'SELECT DISTINCT i.*'
				. ' FROM #__rg_galleryitems AS i'
				. ' LEFT JOIN #__rg_restaurantitems AS h ON h.id = i.resto'
				. ' WHERE h.id = ' . (int)$this->_id
				;

		$this->_db->setQuery($query);
		$gallery = $this->_db->loadObjectList();
		return $gallery;
	}
	
	function getPromotions()
	{
		$query = 'SELECT DISTINCT i.*, h.title AS restoname'
				. ' FROM #__rg_promotions AS i'
				. ' LEFT JOIN #__rg_restaurantitems AS h ON h.id = i.resto'
				. ' WHERE h.id = ' . (int)$this->_id
				;	
				
		$this->_db->setQuery($query);
		$promotions = $this->_db->loadObjectList();
		return $promotions;
	}
	
	function &getArticles()
	{
		if (empty($this->_articles)) {
			$query = 'SELECT DISTINCT c.id, c.title,'
					. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(":", c.id, c.alias) ELSE c.id END as slug,'
         			. ' CASE WHEN CHAR_LENGTH(cc.alias) THEN CONCAT_WS(":", cc.id, cc.alias) ELSE cc.id END as catslug'
					. ' FROM #__content AS c'
					. ' INNER JOIN #__categories AS cc ON cc.id = c.catid' 
         	//		. ' INNER JOIN #__sections AS s ON s.id = c.sectionid' 
					. ' LEFT JOIN #__rg_links AS l ON l.contentid = c.id'
					. ' WHERE l.resto = '.$this->_id
					;
	
			$this->_db->setQuery( $query );
	
			$this->_articles = $this->_db->loadObjectList();
		}

		return $this->_articles;
	}
	
	function getUsedTags()
	{
		$query = 'SELECT DISTINCT t.name,'
				. ' CASE WHEN CHAR_LENGTH(t.alias) THEN CONCAT_WS(\':\', t.id, t.alias) ELSE t.id END as slug'
				. ' FROM #__rg_tags_item_relations AS tag'
				. ' LEFT JOIN #__rg_restaurantitems AS i ON i.id = tag.itemid'
				. ' LEFT JOIN #__rg_tags as t ON t.id = tag.tid'
				. ' WHERE i.id = ' . $this->_id
				. ' ORDER BY t.name'
				;

		$this->_db->setQuery($query);
		$used = $this->_db->loadObjectList();
		return $used;
	}
}
?>