<?php
/**
 * @version 1.0 $Id: restaurantguide_files.php
 * @package Joomla
 * @subpackage RestaurantGuide
 * @copyright (C) 2009-2011 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * RestaurantGuide is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * RestaurantGuide is distribut ed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with RestaurantGuide; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * RestaurantGuide Component Model
 *
 * @package Joomla
 * @subpackage RestaurantGuide
 * @since		1.0
 */
class restaurantguideModelType extends JModel
{
	var $_id = null;
	/**
	 * Data
	 *
	 * @var object
	 */
	var $_data = null;
	
	/**
	 * total
	 *
	 * @var int
	 */
	var $_total = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$app = JFactory::getApplication('site');

		// Get the paramaters of the active menu item
		$params = $app->getParams();
		
		$id = JRequest::getInt('cid', 0);
		
		if (!$id)
			$id = JRequest::getInt('id', 0);

		$this->setId((int)$id);

		//set limits
		$limit		= $app->getUserStateFromRequest('com_restaurantguide.type.limit', 'limit', $params->def('limit', 0), 'int');
		$limitstart		= JRequest::getInt('limitstart');

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);

		$this->setState('filter_order', JRequest::getCmd('filter_order', 'i.title'));
		$this->setState('filter_order_dir', JRequest::getCmd('filter_order_Dir', 'ASC'));
	}
	
	function setId($cid)
	{
		// Set new destination ID and wipe data
		$this->_id = $cid;
	}
	
	/**
	 * Method to get Data
	 *
	 * @access public
	 * @return object
	 */
	function getData()
	{
		// Lets load the categories if it doesn't already exist
		if (empty($this->_data))
		{
			//get data
			$this->_data = $this->_getList( $this->_buildQuery(), $this->getState('limitstart'), $this->getState('limit') );
			
			$count = count($this->_data);

			$i = 0;
			foreach($this->_data as $data) :
				$temp = $data->cuisines;
				$where = ' WHERE published = 1';
				if ($temp) {
					$where .= ' AND id IN ('.$temp.')';
				} else {
					$where .= ' AND id = 0';
				}

				$query = 'SELECT GROUP_CONCAT(DISTINCT name ORDER BY name ASC SEPARATOR \', \') AS cuisines'
					. ' FROM #__rg_cuisines'
					. $where
					;
					
				$this->_db->setQuery($query);
				$this->_data[$i]->cuisinelist = $this->_db->loadObject();
			
				$temp = $data->tags;
				$where = ' WHERE published = 1';
				if ($temp) {
					$where .= ' AND id IN ('.$temp.')';
				} else {
					$where .= ' AND id = 0';
				}
				$query = 'SELECT DISTINCT name,'
						. ' CASE WHEN CHAR_LENGTH(alias) THEN CONCAT_WS(\':\', id, alias) ELSE id END as slug'
						. ' FROM #__rg_tags'
						. $where
						. ' ORDER BY name ASC'
						;
				
				$this->_db->setQuery($query);
				$this->_data[$i]->taglist = $this->_db->loadObjectList();
				
				$query = 'SELECT o.*'
						. ' FROM #__rg_specialoffers AS o'
						. ' LEFT JOIN #__rg_restaurantitems AS i ON i.id = o.resto'
						. ' WHERE o.published = 1'
						. ' AND o.resto = '.$data->id
						. ' ORDER BY o.startdates DESC'
						;
					
				$this->_db->setQuery($query);	
				$this->_data[$i]->offers = $this->_db->loadObjectList();
				
				$i ++;
			endforeach;
		}

		return $this->_data;
	}
	
	function _buildItemWhere( )
	{
		$app = JFactory::getApplication('site');
		$params = $app->getParams();
		
		$where = ' WHERE i.published = 1';
		$where .= ' AND i.tid = '.$this->_id;

		/*
		* If we have a filter, and this is enabled... lets tack the AND clause
		* for the filter onto the WHERE clause of the item query.
		*/
		if ($params->get('filter'))
		{
			$filter = JRequest::getString('filter', '', 'request');

			if ($filter)
			{
				// clean filter variables
				$filter = $this->_db->getEscaped( trim(JString::strtolower( $filter ) ) );

				$where .= ' AND LOWER( i.title ) LIKE '.$this->_db->Quote( '%'.$this->_db->getEscaped( $filter, true ).'%', false );
			}
		}
		return $where;
	}
	
	function _buildItemOrderBy()
	{
		$filter_order		= $this->getState('filter_order');
		$filter_order_dir	= $this->getState('filter_order_dir');

		if ($filter_order == 'title')
			$orderby 	= ' ORDER BY i.title '.$filter_order_dir;
		else if ($filter_order == 'hits')
			$orderby 	= ' ORDER BY i.hits '.$filter_order_dir.', i.title ASC';
		else if ($filter_order == 'votes')
			$orderby 	= ' ORDER BY votes '.$filter_order_dir.', i.title ASC';
		else
			$orderby 	= ' ORDER BY i.title ASC';

		return $orderby;
	}
	
	/**
	 * Method to build the Categories query
	 *
	 * @access private
	 * @return string
	 */
	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildItemWhere();
		$orderby	= $this->_buildItemOrderBy();
	
		$query = 'SELECT DISTINCT i.*, (i.rate_sum / i.rate ) AS votes, t.name AS restauranttype, c.name AS cityname,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug,'	
					. ' (SELECT GROUP_CONCAT('
					. ' tag.tid ORDER BY tag.tid ASC SEPARATOR \', \')'
					. ' FROM #__rg_tags_item_relations AS tag'
					. ' WHERE tag.itemid IN(i.id)'
					. ' )' 
					. ' AS tags'
				. ' FROM #__rg_restaurantitems AS i'
				. ' LEFT JOIN #__rg_restauranttypes AS t ON t.id = i.tid'
				. ' LEFT JOIN #__rg_cities AS c on c.id = i.city'
				. $where
				. $orderby
				; 

		return $query;
	}

	/**
	 * Method to build the Categories query without subselect
	 * That's enough to get the total value.
	 *
	 * @access private
	 * @return string
	 */
	function _buildQueryTotal()
	{
		$query = 'SELECT i.id'
				. ' FROM #__rg_restaurantitems AS i'
				. ' LEFT JOIN #__rg_restauranttypes AS t on t.id = i.tid'
				. ' WHERE i.published = 1'
				. ' AND i.tid = '.$this->_id
				;

		return $query;
	}
	
	/**
	 * Total nr of Categories
	 *
	 * @access public
	 * @return integer
	 */
	function getTotal()
	{
		// Lets load the total nr if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQueryTotal();
			$this->_total = $this->_getListCount($query);
		}

		return $this->_total;
	}

	function getTypes()
	{			
		$query = 'SELECT t.*,'
				. ' CASE WHEN CHAR_LENGTH( t.alias ) THEN CONCAT_WS( \':\', t.id, t.alias ) ELSE t.id END AS slug'
				. ' FROM #__rg_restauranttypes AS t'
				. ' WHERE t.published = 1'
				;
				
		$this->_db->setQuery( $query );
		$results = $this->_db->loadObjectList();

		$i = 0;
		foreach($results as $data) :
			$query = 'SELECT COUNT(i.id) AS assign'
					. ' FROM #__rg_restauranttypes AS t'
					. ' LEFT JOIN #__rg_restaurantitems AS i ON i.tid = t.id'
					. ' WHERE t.id = '.$data->id
					. ' AND i.published = 1'
					;
					
			$this->_db->setQuery( $query );
			$restos = $this->_db->loadObject();
			
			$results[$i]->restos = $restos;
				
			$i ++;	
		endforeach;
				
		return $results;
	}

}
?>